;*****************************************************************************
;				NICST TOOL
;
;  FP-13 Static LWIR Xtalk test. Calculate XF_dn, XF_L, CNR, and PVP using the sum
;  of the dn in the sender band as the sender detector dn.
;  
;  v1.0 - 1/23/2008 - Jeff McIntire
;*****************************************************************************

PRO fp_13_LWIR_sender

n_bands=5

bandname=['I5','M14','M15','M16A','M16B']

uaidname=['3102128','3102155','3102157','3102159','3102161']
n_uaid=N_ELEMENTS(uaidname)
colnum=[34,33,33,64,32]

;*****************************************************************************
;  Create output files.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN

	outfname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.snd_avg_coeff.dat'
	openw,lun,outfname1,/get_lun

;*****************************************************************************
;  Input DN to files for I and M bands.
;*****************************************************************************

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.dn.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	restore,infname1
	restore,infname2

;*****************************************************************************
;  Calculate crosstalk parameters and write to an output file.
;*****************************************************************************

	fmt='(i3, 5x, a5, 5x, i2, 5x, i2, 5x, a5, 5x, i2, 5x, i2, 5x, d, 5x, d, 5x, d, 5x, d)'

	L_max=[15.429,17.561,17.107,14.502,14.502,0]
	L_typ=[1.53,5.14,9.7,8.97,8.97,0]

	n_subset=2
	band_skip=fltarr(colnum[uaid])
	XF_dn=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	XF_L=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	CNR=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	PVP=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	PVP_1=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	PVP_2=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)

	openw,lun,'/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.snd_avg_coeff.dat',/get_lun
	printf,lun,'Collect  S_Band  S_Detector  S_Subset  R_Band  R_Detector  R_Subset   XF_dn   XF_L   CNR   PVP'

	FOR col=0, colnum[uaid]-1 DO BEGIN
		band_skip[col]=0

		; U3102128
		IF uaid EQ 0 THEN BEGIN
			IF col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 OR col EQ 13 $
				OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 OR col EQ 23 $
				OR col EQ 25 OR col EQ 27 OR col EQ 29 OR col EQ 31 OR col EQ 33 THEN band_skip[col]=1
		ENDIF
		; U3102155
		IF uaid EQ 1 THEN BEGIN
			IF col EQ 0 OR col EQ 2 OR col EQ 4 OR col EQ 6 OR col EQ 8 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 $
				OR col EQ 23 OR col EQ 25 OR col EQ 27 OR col EQ 29 OR col EQ 31 THEN band_skip[col]=1
		ENDIF
		; U3102157
		IF uaid EQ 2 THEN BEGIN
			IF col EQ 2 OR col EQ 4 OR col EQ 6 OR col EQ 8 OR col EQ 10 OR col EQ 12 $
				OR col EQ 14 OR col EQ 16 OR col EQ 18 OR col EQ 20 OR col EQ 22 $
				OR col EQ 24 OR col EQ 26 OR col EQ 28 OR col EQ 30 OR col EQ 32 THEN band_skip[col]=1
		ENDIF
		; U3102159
		IF uaid EQ 3 THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 $
				OR col EQ 23 OR col EQ 25 OR col EQ 27 OR col EQ 29 OR col EQ 31 $
				OR col EQ 33 OR col EQ 35 OR col EQ 37 OR col EQ 39 OR col EQ 41 $
				OR col EQ 43 OR col EQ 45 OR col EQ 47 OR col EQ 49 OR col EQ 51 $
				OR col EQ 53 OR col EQ 55 OR col EQ 57 OR col EQ 59 OR col EQ 61 $
				OR col EQ 63 THEN band_skip[col]=1
		ENDIF
		; U3102161
		IF uaid EQ 4 THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 $
				OR col EQ 23 OR col EQ 25 OR col EQ 27 OR col EQ 29 OR col EQ 31 THEN band_skip[col]=1
		ENDIF

		; Sender band (s_band), detector (s_det), and subset (isubset).
		s_band=high_det[col,0]
		s_det=fix(high_det[col,1])

		IF s_band EQ 0 THEN n_subset=2
		IF s_band GE 1 THEN n_subset=1
		FOR isubset=0, n_subset-1 DO BEGIN

			; Receiver band (ib), detector (id), and subset (is).
			FOR ib=0, 4 DO BEGIN
				IF ib EQ 3 THEN BEGIN
					IF band_skip[col] EQ 0 THEN goto,skip_band_r
				ENDIF
				IF ib EQ 1 OR ib EQ 2 THEN BEGIN
					IF band_skip[col] EQ 1 THEN goto,skip_band_s
				ENDIF

				IF ib EQ 0 THEN n_d=32
				IF ib GE 1 THEN n_d=16
				FOR id=0, n_d-1 DO BEGIN

					IF ib EQ 0 THEN n_subset=2
					IF ib GE 1 THEN n_subset=1
					FOR is=0, n_subset-1 DO BEGIN
						IF dn[col,s_band,s_det,isubset] EQ 0 THEN BEGIN
							dn[col,s_band,*,isubset]= $
								dn[col-1,s_band,*,isubset]
						ENDIF
						dn_snd_band=total(dn[col,s_band,*,isubset])

						XF_dn[col,s_det,isubset,ib,id,is]= $
							dn[col,ib,id,is]/dn_snd_band
						XF_L[col,s_det,isubset,ib,id,is]= $
							gain[s_band,s_det,isubset]*dn[col,ib,id,is]/ $
							(gain[ib,id,is]*dn_snd_band)

						PVP_1[col,s_det,isubset,ib,id,is]= $
							2*sqrt(3)*L_max[s_band]*dn[col,ib,id,is]*gain[s_band,s_det,isubset]/ $
							(dn_snd_band*std[col,ib,id,is])
						PVP_2[col,s_det,isubset,ib,id,is]= $
							L_max[s_band]*dn[col,ib,id,is]*gain[s_band,s_det,isubset]/ $
							(dn_snd_band*gain[ib,id,is]*0.002*L_typ[ib])
						IF abs(PVP_2[col,s_det,isubset,ib,id,is]) GT $
							abs(PVP_1[col,s_det,isubset,ib,id,is]) THEN BEGIN
							PVP[col,s_det,isubset,ib,id,is]=PVP_1[col,s_det,isubset,ib,id,is]
						ENDIF ELSE BEGIN
							PVP[col,s_det,isubset,ib,id,is]=PVP_2[col,s_det,isubset,ib,id,is]
						ENDELSE
						CNR[col,s_det,isubset,ib,id,is]=PVP_1[col,s_det,isubset,ib,id,is]/4
						printf,lun,format=fmt,col+1,bandname[s_band], $
							s_det+1,isubset,bandname[ib],id+1,is, $
							XF_dn[col,s_det,isubset,ib,id,is], $
							XF_L[col,s_det,isubset,ib,id,is], $
							CNR[col,s_det,isubset,ib,id,is], $
							PVP[col,s_det,isubset,ib,id,is]
					ENDFOR
				ENDFOR
				skip_band_r:
				skip_band_s:
			ENDFOR
		ENDFOR
		skip_col:

		save,/compress,gain,XF_dn,XF_L,CNR,PVP,filename='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+ $
			uaidname[uaid]+'.snd_avg_coeff.sav'
	ENDFOR
	close,lun,/file,/all
	free_lun,lun

	skip:
ENDFOR

END
