;*****************************************************************************
;				NICST TOOL
;
;  Band average the FP-13 LWIR crosstalk coefficients.
;  
;  v1.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO LWIR_det_avg

close,/all

ndet_I=32
ndet_M=16

uaidname=['3102128','3102155','3102157','3102159','3102161']
n_uaid=N_ELEMENTS(uaidname)
colnum=[34,33,33,64,32]

fmt='(d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13)'
header='I5_SS1  I5_SS2  M16A  M16B  M15  M14'

;*****************************************************************************
;  Read in data and create output files.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN
	outfname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.det_avg.dn.dat'
	outfname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.det_avg.L.dat'
	outfname3='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.det_avg.CNR.dat'
	openw,lun,outfname1,/get_lun
	openw,lon,outfname2,/get_lun
	openw,len,outfname3,/get_lun
	printf,lun,header
	printf,lon,header
	printf,len,header

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.dn.sav'
;	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.snd_avg_coeff.sav'
	infname3='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.reform.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	print,'Processing file:',infname3
	restore,infname1
	restore,infname2
	restore,infname3

	; reformed data
	XF_dn_I_det_avg=fltarr(ndet_I,2,2,2)
	XF_L_I_det_avg=fltarr(ndet_I,2,2,2)
	CNR_I_det_avg=fltarr(ndet_I,2,2,2)
	XF_dn_M_det_avg=fltarr(ndet_I,2,6)
	XF_L_M_det_avg=fltarr(ndet_I,2,6)
	CNR_M_det_avg=fltarr(ndet_I,2,6)

	; reformed data for dual gain bands
	XF_dn_I_det_avg_g=fltarr(ndet_I,2,2,2,2,2)
	XF_L_I_det_avg_g=fltarr(ndet_I,2,2,2,2,2)
	CNR_I_det_avg_g=fltarr(ndet_I,2,2,2,2,2)
	XF_dn_M_det_avg_g=fltarr(ndet_I,2,6,2,2)
	XF_L_M_det_avg_g=fltarr(ndet_I,2,6,2,2)
	CNR_M_det_avg_g=fltarr(ndet_I,2,6,2,2)

;*****************************************************************************
;  Skip bad collects and reform data.
;*****************************************************************************

	count1=0
	count2=0
	FOR col=0, colnum[uaid]-1 DO BEGIN
		flag=0

		; U3102128
		IF uaid EQ 0 THEN BEGIN
			IF col EQ 0 OR col EQ 1 THEN goto,skip_col
		ENDIF

		; U3102155
		IF uaid EQ 1 THEN BEGIN
			IF col EQ 10 THEN goto,skip_col
		ENDIF

		; U3102157
		IF uaid EQ 2 THEN BEGIN
			IF col EQ 0 THEN goto,skip_col
		ENDIF


		band_lit=fix(high_det[col,0])
		det_lit=fix(high_det[col,1])

		XF_dn_I=fltarr(ndet_I,2,2,ndet_I,2)
		XF_L_I=fltarr(ndet_I,2,2,ndet_I,2)
		CNR_I=fltarr(ndet_I,2,2,ndet_I,2)
		FOR j=0, 0 DO BEGIN
			FOR i=0, ndet_I-1, 2 DO BEGIN
				XF_dn_I[*,*,j,i,0]=XF_dn[col,*,*,j,i,0]
				XF_dn_I[*,*,j,i+1,0]=XF_dn[col,*,*,j,i+1,1]
				XF_dn_I[*,*,j,i,1]=XF_dn[col,*,*,j,i,1]
				XF_dn_I[*,*,j,i+1,1]=XF_dn[col,*,*,j,i+1,0]

				XF_L_I[*,*,j,i,0]=XF_L[col,*,*,j,i,0]
				XF_L_I[*,*,j,i+1,0]=XF_L[col,*,*,j,i+1,1]
				XF_L_I[*,*,j,i,1]=XF_L[col,*,*,j,i,1]
				XF_L_I[*,*,j,i+1,1]=XF_L[col,*,*,j,i+1,0]

				CNR_I[*,*,j,i,0]=CNR[col,*,*,j,i,0]
				CNR_I[*,*,j,i+1,0]=CNR[col,*,*,j,i+1,1]
				CNR_I[*,*,j,i,1]=CNR[col,*,*,j,i,1]
				CNR_I[*,*,j,i+1,1]=CNR[col,*,*,j,i+1,0]
			ENDFOR
		ENDFOR

		XF_dn_M=(reform(XF_dn[col,*,*,1:4,0:15,0]))
		XF_L_M=(reform(XF_L[col,*,*,1:4,0:15,0]))
		CNR_M=(reform(CNR[col,*,*,1:4,0:15,0]))

		IF band_lit LE 0 THEN n_det=32
		IF band_lit LE 0 THEN n_s=2
		IF band_lit GE 1 THEN n_det=16
		IF band_lit GE 1 THEN n_s=1

;*****************************************************************************
;  Make subsample 1 for the I bands higher.
;*****************************************************************************

		XF_dn_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		XF_L_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		CNR_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		FOR s_s=0, n_s-1 DO BEGIN
			FOR r_s=0, 1 DO BEGIN
				FOR ib=0, 0 DO BEGIN
					IF mean(XF_L_I[det_lit,s_s,ib,*,0]) GT $
						mean(XF_L_I[det_lit,s_s,ib,*,1]) THEN BEGIN
						FOR id=0, ndet_I-1 DO BEGIN

							XF_dn_I_t[det_lit,s_s,ib,id,0]=XF_dn_I[det_lit,s_s,ib,id,0]
							XF_dn_I_t[det_lit,s_s,ib,id,1]=XF_dn_I[det_lit,s_s,ib,id,1]
							XF_L_I_t[det_lit,s_s,ib,id,0]=XF_L_I[det_lit,s_s,ib,id,0]
							XF_L_I_t[det_lit,s_s,ib,id,1]=XF_L_I[det_lit,s_s,ib,id,1]
							CNR_I_t[det_lit,s_s,ib,id,0]=CNR_I[det_lit,s_s,ib,id,0]
							CNR_I_t[det_lit,s_s,ib,id,1]=CNR_I[det_lit,s_s,ib,id,1]
						ENDFOR
					ENDIF
					IF mean(XF_L_I[det_lit,s_s,ib,*,1]) GT $
						mean(XF_L_I[det_lit,s_s,ib,*,0]) THEN BEGIN
						FOR id=0, ndet_I-1 DO BEGIN

							XF_dn_I_t[det_lit,s_s,ib,id,0]=XF_dn_I[det_lit,s_s,ib,id,1]
							XF_dn_I_t[det_lit,s_s,ib,id,1]=XF_dn_I[det_lit,s_s,ib,id,0]
							XF_L_I_t[det_lit,s_s,ib,id,0]=XF_L_I[det_lit,s_s,ib,id,1]
							XF_L_I_t[det_lit,s_s,ib,id,1]=XF_L_I[det_lit,s_s,ib,id,0]
							CNR_I_t[det_lit,s_s,ib,id,0]=CNR_I[det_lit,s_s,ib,id,1]
							CNR_I_t[det_lit,s_s,ib,id,1]=CNR_I[det_lit,s_s,ib,id,0]
						ENDFOR
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
		XF_dn_I[*,*,*,*,*]=XF_dn_I_t[*,*,*,*,*]
		XF_L_I[*,*,*,*,*]=XF_L_I_t[*,*,*,*,*]
		CNR_I[*,*,*,*,*]=CNR_I_t[*,*,*,*,*]

;*****************************************************************************
;  Band average, taking into acount the band substitution tables for each UAID and collect.
;*****************************************************************************

		FOR ib=0, 0 DO BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				FOR r_s=0, 1 DO BEGIN
					XF_dn_I_det_avg[det_lit,s_s,ib,r_s]=XF_dn_I_det_avg[det_lit,s_s,ib,r_s] $
						+mean(XF_dn_I[det_lit,s_s,ib,*,r_s])
					XF_L_I_det_avg[det_lit,s_s,ib,r_s]=XF_L_I_det_avg[det_lit,s_s,ib,r_s] $
						+mean(XF_L_I[det_lit,s_s,ib,*,r_s])
					CNR_I_det_avg[det_lit,s_s,ib,r_s]=CNR_I_det_avg[det_lit,s_s,ib,r_s] $
						+mean(CNR_I[det_lit,s_s,ib,*,r_s])
				ENDFOR
			ENDFOR
		ENDFOR
		count1=count1+1
		IF count1 EQ 2 THEN BEGIN
			XF_dn_I_det_avg[det_lit,*,*,*]=XF_dn_I_det_avg[det_lit,*,*,*]/2
			XF_L_I_det_avg[det_lit,*,*,*]=XF_L_I_det_avg[det_lit,*,*,*]/2
			CNR_I_det_avg[det_lit,*,*,*]=CNR_I_det_avg[det_lit,*,*,*]/2
			count1=0
		ENDIF
		FOR ib=0, 3 DO BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				XF_dn_M_det_avg[det_lit,s_s,ib]=XF_dn_M_det_avg[det_lit,s_s,ib] $
					+mean(XF_dn_M[det_lit,s_s,ib,*])
				XF_L_M_det_avg[det_lit,s_s,ib]=XF_L_M_det_avg[det_lit,s_s,ib] $
					+mean(XF_L_M[det_lit,s_s,ib,*])
				CNR_M_det_avg[det_lit,s_s,ib]=CNR_M_det_avg[det_lit,s_s,ib] $
					+mean(CNR_M[det_lit,s_s,ib,*])
			ENDFOR
		ENDFOR
		count2=count2+1
		IF count2 EQ 2 THEN BEGIN
			XF_dn_M_det_avg[det_lit,*,3]=XF_dn_M_det_avg[det_lit,*,3]/2
			XF_L_M_det_avg[det_lit,*,3]=XF_L_M_det_avg[det_lit,*,3]/2
			CNR_M_det_avg[det_lit,*,3]=CNR_M_det_avg[det_lit,*,3]/2
			count2=0
		ENDIF

		skip_col:

	ENDFOR

	IF uaid EQ 3 THEN n_s=2
	IF uaid NE 3 THEN n_s=1
	IF uaid EQ 3 THEN n_det=32
	IF uaid NE 3 THEN n_det=16

	FOR s_s=0, n_s-1 DO BEGIN
		FOR r_s=0, 1 DO BEGIN
			FOR s_det=0, n_det-1 DO BEGIN
				IF abs(CNR_I_det_avg[s_det,s_s,r_s]) GT 1 THEN print,'I',s_det+1,r_s 
			ENDFOR
		ENDFOR
	ENDFOR
	FOR s_s=0, n_s-1 DO BEGIN
		FOR ib=0, 3 DO BEGIN
			FOR s_det=0, n_det-1 DO BEGIN
				IF abs(CNR_M_det_avg[s_det,s_s,ib]) GT 1 THEN print,'M',s_det+1,ib
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Print to file.
;*****************************************************************************

	FOR s_s=0, n_s-1 DO BEGIN
		FOR s_det=0, n_det-1 DO BEGIN
			printf,lun,XF_dn_I_det_avg[s_det,s_s,0,0],XF_dn_I_det_avg[s_det,s_s,0,1], $
				XF_dn_M_det_avg[s_det,s_s,2],XF_dn_M_det_avg[s_det,s_s,3], $
				XF_dn_M_det_avg[s_det,s_s,1],XF_dn_M_det_avg[s_det,s_s,0],format=fmt
			printf,lon,XF_L_I_det_avg[s_det,s_s,0,0],XF_L_I_det_avg[s_det,s_s,0,1], $
				XF_L_M_det_avg[s_det,s_s,2],XF_L_M_det_avg[s_det,s_s,3], $
				XF_L_M_det_avg[s_det,s_s,1],XF_L_M_det_avg[s_det,s_s,0],format=fmt
			printf,len,CNR_I_det_avg[s_det,s_s,0,0],CNR_I_det_avg[s_det,s_s,0,1], $
				CNR_M_det_avg[s_det,s_s,2],CNR_M_det_avg[s_det,s_s,3], $
				CNR_M_det_avg[s_det,s_s,1],CNR_M_det_avg[s_det,s_s,0],format=fmt
		ENDFOR
	ENDFOR

	Free_Lun,lun
	close,/all

	skip_loop:
ENDFOR

close,/all

END
