;*****************************************************************************
;				NICST TOOL
;
;  Odd - even average the FP-13 LWIR crosstalk coefficients.
;  
;  v1.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO LWIR_odd_even

close,/all

band_name=['I5','M14','M15','M16A','M16B']
nband=n_elements(band_name)
ndet_I=32
ndet_M=16

uaidname=['3102128','3102155','3102157','3102159','3102161']
n_uaid=N_ELEMENTS(uaidname)
colnum=[34,33,33,64,32]

fmt='(d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13)'
header='I5_SS1_odd  I5_SS1_even  I5_SS2_odd  I5_SS2_even  M16A_odd  M16A_even  M16B_odd  M16B_even  M15_odd  M15_even  M14_odd  M14_even'

;*****************************************************************************
;  Read in data and create output files.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN
	outfname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.odd_even.dn.dat'
	outfname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.odd_even.L.dat'
	outfname3='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.odd_even.CNR.dat'
	openw,lun,outfname1,/get_lun
	openw,lon,outfname2,/get_lun
	openw,len,outfname3,/get_lun
	printf,lun,header
	printf,lon,header
	printf,len,header

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.dn.sav'
;	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.snd_avg_coeff.sav'
	infname3='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.reform.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	print,'Processing file:',infname3
	restore,infname1
	restore,infname2
	restore,infname3

	; reformed data
	XF_dn_I_odd=fltarr(ndet_I,2,2,2)
	XF_dn_I_even=fltarr(ndet_I,2,2,2)
	XF_L_I_odd=fltarr(ndet_I,2,2,2)
	XF_L_I_even=fltarr(ndet_I,2,2,2)
	CNR_I_odd=fltarr(ndet_I,2,2,2)
	CNR_I_even=fltarr(ndet_I,2,2,2)
	XF_dn_M_odd=fltarr(ndet_I,2,6)
	XF_dn_M_even=fltarr(ndet_I,2,6)
	XF_L_M_odd=fltarr(ndet_I,2,6)
	XF_L_M_even=fltarr(ndet_I,2,6)
	CNR_M_odd=fltarr(ndet_I,2,6)
	CNR_M_even=fltarr(ndet_I,2,6)

	; reformed data for dual gain bands
	XF_dn_I_odd_g=fltarr(ndet_I,2,2,2,2,2)
	XF_dn_I_even_g=fltarr(ndet_I,2,2,2,2,2)
	XF_L_I_odd_g=fltarr(ndet_I,2,2,2,2,2)
	XF_L_I_even_g=fltarr(ndet_I,2,2,2,2,2)
	CNR_I_odd_g=fltarr(ndet_I,2,2,2,2,2)
	CNR_I_even_g=fltarr(ndet_I,2,2,2,2,2)
	XF_dn_M_odd_g=fltarr(ndet_I,2,6,2,2)
	XF_dn_M_even_g=fltarr(ndet_I,2,6,2,2)
	XF_L_M_odd_g=fltarr(ndet_I,2,6,2,2)
	XF_L_M_even_g=fltarr(ndet_I,2,6,2,2)
	CNR_M_odd_g=fltarr(ndet_I,2,6,2,2)
	CNR_M_even_g=fltarr(ndet_I,2,6,2,2)

;*****************************************************************************
;  Skip bad collects and reform data.
;*****************************************************************************

	count1=0
	count2=0
	FOR col=0, colnum[uaid]-1 DO BEGIN

		; U3102128
		IF uaid EQ 0 THEN BEGIN
			IF col EQ 0 OR col EQ 1 THEN goto,skip_col
		ENDIF
;		IF uaid EQ 0 THEN BEGIN
;			IF col EQ 0 OR col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 $
;				OR col EQ 11 OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 $
;				OR col EQ 21 OR col EQ 23 OR col EQ 25 OR col EQ 27 OR col EQ 29 $ 
;				OR col EQ 31 OR col EQ 33 THEN goto,skip_col
;		ENDIF

		; U3102155
		IF uaid EQ 1 THEN BEGIN
			IF col EQ 10 THEN goto,skip_col
		ENDIF

		; U3102157
		IF uaid EQ 2 THEN BEGIN
			IF col EQ 0 THEN goto,skip_col
		ENDIF

		; U3102161
;		IF uaid EQ 4 THEN BEGIN
;			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
;				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 $
;				OR col EQ 23 OR col EQ 25 OR col EQ 27 OR col EQ 29 OR col EQ 31 $
;				THEN goto,skip_col
;		ENDIF

		band_lit=fix(high_det[col,0])
		det_lit=fix(high_det[col,1])

		XF_dn_I=fltarr(ndet_I,2,2,ndet_I,2)
		XF_L_I=fltarr(ndet_I,2,2,ndet_I,2)
		CNR_I=fltarr(ndet_I,2,2,ndet_I,2)
		FOR j=0, 0 DO BEGIN
			FOR i=0, ndet_I-1, 2 DO BEGIN
				XF_dn_I[*,*,j,i,0]=XF_dn[col,*,*,j,i,0]
				XF_dn_I[*,*,j,i+1,0]=XF_dn[col,*,*,j,i+1,1]
				XF_dn_I[*,*,j,i,1]=XF_dn[col,*,*,j,i,1]
				XF_dn_I[*,*,j,i+1,1]=XF_dn[col,*,*,j,i+1,0]

				XF_L_I[*,*,j,i,0]=XF_L[col,*,*,j,i,0]
				XF_L_I[*,*,j,i+1,0]=XF_L[col,*,*,j,i+1,1]
				XF_L_I[*,*,j,i,1]=XF_L[col,*,*,j,i,1]
				XF_L_I[*,*,j,i+1,1]=XF_L[col,*,*,j,i+1,0]

				CNR_I[*,*,j,i,0]=CNR[col,*,*,j,i,0]
				CNR_I[*,*,j,i+1,0]=CNR[col,*,*,j,i+1,1]
				CNR_I[*,*,j,i,1]=CNR[col,*,*,j,i,1]
				CNR_I[*,*,j,i+1,1]=CNR[col,*,*,j,i+1,0]
			ENDFOR
		ENDFOR

		XF_dn_M=(reform(XF_dn[col,*,*,1:4,0:15,0]))
		XF_L_M=(reform(XF_L[col,*,*,1:4,0:15,0]))
		CNR_M=(reform(CNR[col,*,*,1:4,0:15,0]))

		IF band_lit LE 0 THEN n_det=32
		IF band_lit LE 0 THEN n_s=2
		IF band_lit GE 1 THEN n_det=16
		IF band_lit GE 1 THEN n_s=1

;*****************************************************************************
;  Make subsample 1 for the I bands higher.
;*****************************************************************************

		XF_dn_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		XF_L_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		CNR_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		FOR s_s=0, n_s-1 DO BEGIN
			FOR r_s=0, 1 DO BEGIN
				FOR ib=0, 0 DO BEGIN
					IF mean(XF_L_I[det_lit,s_s,ib,*,0]) GT $
						mean(XF_L_I[det_lit,s_s,ib,*,1]) THEN BEGIN
						FOR id=0, ndet_I-1 DO BEGIN

							XF_dn_I_t[det_lit,s_s,ib,id,0]=XF_dn_I[det_lit,s_s,ib,id,0]
							XF_dn_I_t[det_lit,s_s,ib,id,1]=XF_dn_I[det_lit,s_s,ib,id,1]
							XF_L_I_t[det_lit,s_s,ib,id,0]=XF_L_I[det_lit,s_s,ib,id,0]
							XF_L_I_t[det_lit,s_s,ib,id,1]=XF_L_I[det_lit,s_s,ib,id,1]
							CNR_I_t[det_lit,s_s,ib,id,0]=CNR_I[det_lit,s_s,ib,id,0]
							CNR_I_t[det_lit,s_s,ib,id,1]=CNR_I[det_lit,s_s,ib,id,1]
						ENDFOR
					ENDIF
					IF mean(XF_L_I[det_lit,s_s,ib,*,1]) GT $
						mean(XF_L_I[det_lit,s_s,ib,*,0]) THEN BEGIN
						FOR id=0, ndet_I-1 DO BEGIN

							XF_dn_I_t[det_lit,s_s,ib,id,0]=XF_dn_I[det_lit,s_s,ib,id,1]
							XF_dn_I_t[det_lit,s_s,ib,id,1]=XF_dn_I[det_lit,s_s,ib,id,0]
							XF_L_I_t[det_lit,s_s,ib,id,0]=XF_L_I[det_lit,s_s,ib,id,1]
							XF_L_I_t[det_lit,s_s,ib,id,1]=XF_L_I[det_lit,s_s,ib,id,0]
							CNR_I_t[det_lit,s_s,ib,id,0]=CNR_I[det_lit,s_s,ib,id,1]
							CNR_I_t[det_lit,s_s,ib,id,1]=CNR_I[det_lit,s_s,ib,id,0]
						ENDFOR
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
		XF_dn_I[det_lit,*,*,*,*]=XF_dn_I_t[det_lit,*,*,*,*]
		XF_L_I[det_lit,*,*,*,*]=XF_L_I_t[det_lit,*,*,*,*]
		CNR_I[det_lit,*,*,*,*]=CNR_I_t[det_lit,*,*,*,*]

;*****************************************************************************
;  Odd - even average.
;*****************************************************************************

		FOR s_s=0, n_s-1 DO BEGIN
			FOR r_s=0, 1 DO BEGIN
				FOR ib=0, 0 DO BEGIN
					count1=0
					FOR id=0, ndet_I-1 DO BEGIN
						IF count1 EQ 0 THEN BEGIN
							XF_dn_I_odd[det_lit,s_s,ib,r_s]=XF_dn_I_odd[det_lit,s_s,ib,r_s]+ $
								XF_dn_I[det_lit,s_s,ib,id,r_s]
							XF_L_I_odd[det_lit,s_s,ib,r_s]=XF_L_I_odd[det_lit,s_s,ib,r_s]+ $
								XF_L_I[det_lit,s_s,ib,id,r_s]
							CNR_I_odd[det_lit,s_s,ib,r_s]=CNR_I_odd[det_lit,s_s,ib,r_s]+ $
								CNR_I[det_lit,s_s,ib,id,r_s]
							count1=1
							goto,skip_over_1
						ENDIF
						IF count1 EQ 1 THEN BEGIN
							XF_dn_I_even[det_lit,s_s,ib,r_s]=XF_dn_I_even[det_lit,s_s,ib,r_s]+ $
								XF_dn_I[det_lit,s_s,ib,id,r_s]
							XF_L_I_even[det_lit,s_s,ib,r_s]=XF_L_I_even[det_lit,s_s,ib,r_s]+ $
								XF_L_I[det_lit,s_s,ib,id,r_s]
							CNR_I_even[det_lit,s_s,ib,r_s]=CNR_I_even[det_lit,s_s,ib,r_s]+ $
								CNR_I[det_lit,s_s,ib,id,r_s]
							count1=0
						ENDIF
						skip_over_1:
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR

		FOR ib=0, 3 DO BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				count3=0
				FOR id=0, ndet_M-1 DO BEGIN
					IF count3 EQ 0 THEN BEGIN
						XF_dn_M_odd[det_lit,s_s,ib]=XF_dn_M_odd[det_lit,s_s,ib]+ $
							XF_dn_M[det_lit,s_s,ib,id]
						XF_L_M_odd[det_lit,s_s,ib]=XF_L_M_odd[det_lit,s_s,ib]+ $
							XF_L_M[det_lit,s_s,ib,id]
						CNR_M_odd[det_lit,s_s,ib]=CNR_M_odd[det_lit,s_s,ib]+ $
							CNR_M[det_lit,s_s,ib,id]
						count3=1
						goto,skip_over_2
					ENDIF
					IF count3 EQ 1 THEN BEGIN
						XF_dn_M_even[det_lit,s_s,ib]=XF_dn_M_even[det_lit,s_s,ib]+ $
							XF_dn_M[det_lit,s_s,ib,id]
						XF_L_M_even[det_lit,s_s,ib]=XF_L_M_even[det_lit,s_s,ib]+ $
							XF_L_M[det_lit,s_s,ib,id]
						CNR_M_even[det_lit,s_s,ib]=CNR_M_even[det_lit,s_s,ib]+ $
							CNR_M[det_lit,s_s,ib,id]
						count3=0
					ENDIF
					skip_over_2:
				ENDFOR
			ENDFOR
		ENDFOR

		skip_col:

	ENDFOR

	XF_dn_I_odd[*,*,*,*]=XF_dn_I_odd[*,*,*,*]/32
	XF_dn_I_even[*,*,*,*]=XF_dn_I_even[*,*,*,*]/32
	XF_L_I_odd[*,*,*,*]=XF_L_I_odd[*,*,*,*]/32
	XF_L_I_even[*,*,*,*]=XF_L_I_even[*,*,*,*]/32
	CNR_I_odd[*,*,*,*]=CNR_I_odd[*,*,*,*]/32
	CNR_I_even[*,*,*,*]=CNR_I_even[*,*,*,*]/32

	XF_dn_M_odd[*,*,3]=XF_dn_M_odd[*,*,3]/16
	XF_dn_M_even[*,*,3]=XF_dn_M_even[*,*,3]/16
	XF_L_M_odd[*,*,3]=XF_L_M_odd[*,*,3]/16
	XF_L_M_even[*,*,3]=XF_L_M_even[*,*,3]/16
	CNR_M_odd[*,*,3]=CNR_M_odd[*,*,3]/16
	CNR_M_even[*,*,3]=CNR_M_even[*,*,3]/16

	XF_dn_M_odd[*,*,0:2]=XF_dn_M_odd[*,*,0:2]/8
	XF_dn_M_even[*,*,0:2]=XF_dn_M_even[*,*,0:2]/8
	XF_L_M_odd[*,*,0:2]=XF_L_M_odd[*,*,0:2]/8
	XF_L_M_even[*,*,0:2]=XF_L_M_even[*,*,0:2]/8
	CNR_M_odd[*,*,0:2]=CNR_M_odd[*,*,0:2]/8
	CNR_M_even[*,*,0:2]=CNR_M_even[*,*,0:2]/8

	IF uaid EQ 3 THEN n_s=2
	IF uaid NE 3 THEN n_s=1
	IF uaid EQ 3 THEN n_det=32
	IF uaid NE 3 THEN n_det=16

;*****************************************************************************
;  Write to a file.
;*****************************************************************************

	FOR s_s=0, n_s-1 DO BEGIN
		FOR s_det=0, n_det-1 DO BEGIN
			printf,lun,XF_dn_I_odd[s_det,s_s,0,0],XF_dn_I_even[s_det,s_s,0,0],XF_dn_I_odd[s_det,s_s,0,1], $
				XF_dn_I_even[s_det,s_s,0,1],XF_dn_M_odd[s_det,s_s,2],XF_dn_M_even[s_det,s_s,2], $
				XF_dn_M_odd[s_det,s_s,3],XF_dn_M_even[s_det,s_s,3],XF_dn_M_odd[s_det,s_s,1], $
				XF_dn_M_even[s_det,s_s,1],XF_dn_M_odd[s_det,s_s,0],XF_dn_M_even[s_det,s_s,0],format=fmt
			printf,lon,XF_L_I_odd[s_det,s_s,0,0],XF_L_I_even[s_det,s_s,0,0],XF_L_I_odd[s_det,s_s,0,1], $
				XF_L_I_even[s_det,s_s,0,1],XF_L_M_odd[s_det,s_s,2],XF_L_M_even[s_det,s_s,2], $
				XF_L_M_odd[s_det,s_s,3],XF_L_M_even[s_det,s_s,3],XF_L_M_odd[s_det,s_s,1], $
				XF_L_M_even[s_det,s_s,1],XF_L_M_odd[s_det,s_s,0],XF_L_M_even[s_det,s_s,0],format=fmt
			printf,len,CNR_I_odd[s_det,s_s,0,0],CNR_I_even[s_det,s_s,0,0],CNR_I_odd[s_det,s_s,0,1], $
				CNR_I_even[s_det,s_s,0,1],CNR_M_odd[s_det,s_s,2],CNR_M_even[s_det,s_s,2], $
				CNR_M_odd[s_det,s_s,3],CNR_M_even[s_det,s_s,3],CNR_M_odd[s_det,s_s,1], $
				CNR_M_even[s_det,s_s,1],CNR_M_odd[s_det,s_s,0],CNR_M_even[s_det,s_s,0],format=fmt
		ENDFOR
	ENDFOR

	Free_Lun,lun
	close,/all

	skip_loop:
ENDFOR

close,/all

END
