;*****************************************************************************
;				NICST TOOL
;
;  FP-13 Static LWIR Xtalk test. Calculate XF_dn, XF_L, and CNR.
;
;  INPUTS:
;  1) inpath -- path to directory with dumped files from a specific UAID.
;  
;  v1.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO fp_13_LWIR_read_dn_ev, inpath

; Get list of .dmp files from specified path. 
spawn, 'ls -C1 ' + inpath + '*.dmp', list_files
IF N_ELEMENTS(list_files) EQ 0 THEN goto,skipout
nfile=N_ELEMENTS(list_files)

n_bands=5					; # of bands.
n_collects=nfile/6				; # of collects.
n_subset=2					; # subsets (I bands both indices; M bands only use the first index).
n_ham=2						; # HAM sides.
shutter=fltarr(n_collects)			; Records shutter order per collect.
band_info=fltarr(n_collects,n_bands,2)		; Records # of detectors and scans per band.
high_det=fltarr(n_collects,2)			; Records the high detector number and associated band number.
high_det[*,1]=-1
band_skip=fltarr(nfile)				; Records which files have no data.

bandname=['I5','M14','M15','M16A','M16B']
outfile=' '					; Output file name, which is reasigned.

; DN values per collect (32 possible detectors and 16 possible scans).
dn_collect=dblarr(n_collects,n_bands,n_ham,32,n_subset,16)
std_collect=dblarr(n_collects,n_bands,n_ham,32,n_subset,16)
dn=dblarr(n_collects,n_bands,32,n_subset)
std=dblarr(n_collects,n_bands,32,n_subset)

;*****************************************************************************
;  Read in file with change in shutter order for band substitution.
;*****************************************************************************

openr,lun,'/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/u3102128_scan.txt',/get_lun
n_lines=File_Lines('/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/u3102128_scan.txt')

awa=''
coll_name=intarr(n_lines)		; Collect name.
scan_b_coll=fltarr(n_lines)		; Scans between collect.
change_order=fltarr(n_lines)		; Change in shutter order between collect.

FOR ix=0, n_lines-1 DO BEGIN
	readf,lun,awa
	a7=strsplit(awa,String(9B),/Extract)
	coll_name(ix)=a7(0)
	scan_b_coll(ix)=a7(1)
	change_order(ix)=a7(2)
ENDFOR

close,lun,/file,/all
free_lun,lun

;*****************************************************************************
;  Main program. Read data from dump files.
;*****************************************************************************

FOR ifile=0, nfile-1 DO BEGIN

	print,list_files[ifile]
	nlines=File_Lines(list_files[ifile])
	band_skip[ifile]=0
	IF nlines EQ 0 THEN BEGIN
		band_skip[ifile]=1
		goto,skip
	ENDIF

	read_dmpd,list_files[ifile],uaid,collect,scan,ham,apid,band,dnb_s,det,dsect,frame,offset,gain_type,dns

	max_scan=max(scan)		; Total # scans.
	max_det=max(det)		; Total # detectors.
	max_frame=max(frame)+1		; Total # frames.

	; Determine if it is M or I band.
	a2=strsplit(list_files[ifile],'/',/Extract)
	a3=N_ELEMENTS(a2)
	a4=strmid(a2[a3-1],strpos(a2[a3-1],'_',/Reverse_Search)+1,1)

	; Determine the collect #.
	a5=fix(strmid(a2[a3-1],strpos(a2[a3-1],'_',/Reverse_Search)-3,3))

	; Output file name.
	outfile='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/'+strmid(a2[a3-1],strpos(a2[a3-1],'/',/Reverse_Search)+1,8)

	; Translate the band name to a number.
	IF band[0] EQ 'I5' THEN b=0
	IF band[0] EQ 'M14' THEN b=1
	IF band[0] EQ 'M15' THEN b=2
	IF band[0] EQ 'M16A' THEN b=3
	IF band[0] EQ 'M16B' THEN b=4

;*****************************************************************************
;  Write DN values to an array.
;*****************************************************************************

	dn_frame=dblarr(n_ham,max_det,n_subset,max_scan,max_frame)
	iscan=0
	idet=0
	iframe=0
	subset=0
	FOR i=0L, nlines-1 DO BEGIN
		IF scan[i] EQ iscan+1 AND det[i] EQ idet+1 THEN BEGIN
			dn_frame[ham[i],idet,subset,iscan,iframe]=dns[i]
			iframe=iframe+1
			IF iframe EQ max_frame THEN BEGIN
				idet=idet+1
				iframe=0
				IF idet EQ max_det THEN BEGIN
					idet=0
					iscan=iscan+1
				ENDIF
			ENDIF
		ENDIF
		IF a4 EQ 'I' THEN BEGIN
			IF subset EQ 0 THEN BEGIN
				subset=1
				goto,skip_over
			ENDIF
			IF subset EQ 1 THEN subset=0
			skip_over:
		ENDIF
	ENDFOR

;*****************************************************************************
;  Average over frames.
;*****************************************************************************

	dn_frame_avg=dblarr(n_ham,max_det,n_subset,max_scan)
	std_frame_avg=dblarr(n_ham,max_det,n_subset,max_scan)
	FOR iham=0, n_ham-1 DO BEGIN
		FOR idet=0, max_det-1 DO BEGIN
			FOR isubset=0, n_subset-1 DO BEGIN
				FOR iscan=0, max_scan-1 DO BEGIN
					dn_frame_avg[iham,idet,isubset,iscan]= $
						sig_mean(dn_frame[iham,idet,isubset,iscan,0:max_frame-1],3,1)
					std_frame_avg[iham,idet,isubset,iscan]= $
						sig_mean(dn_frame[iham,idet,isubset,iscan,0:max_frame-1],3,2)
					IF dn_frame_avg[iham,idet,isubset,iscan] EQ -999 THEN BEGIN
						dn_frame_avg[iham,idet,isubset,iscan]=0
					ENDIF
					IF std_frame_avg[iham,idet,isubset,iscan] EQ -999 THEN BEGIN
						std_frame_avg[iham,idet,isubset,iscan]=0
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Pick out the detector with the open shutter and shutter order.
;*****************************************************************************

	; Only consider subset=0.
	count=0
	order=fltarr(4)
	FOR iham=0, n_ham-1 DO BEGIN
		FOR idet=0, max_det-1 DO BEGIN
			FOR iscan=0, 3 DO BEGIN
				IF dn_frame_avg[iham,idet,0,iscan] GT 1000 THEN BEGIN
					high_det[a5-1,0]=b
					high_det[a5-1,1]=idet
					count=count+1
					order[iscan]=1

					IF count EQ 2 THEN goto,M_high_det_found
				ENDIF
			ENDFOR
		ENDFOR
	ENDFOR
	M_high_det_found:

	IF b EQ 4 AND high_det[a5-1,1] EQ -1 THEN BEGIN
		high_det[a5-1,0]=high_det[a5-2,0]
		high_det[a5-1,1]=high_det[a5-2,1]
	ENDIF

	IF b EQ 0 THEN shutter[a5-1]=-1
	IF order[0] EQ 1 AND order[1] EQ 1 THEN shutter[a5-1]=1
	IF order[0] EQ 1 AND order[3] EQ 1 THEN shutter[a5-1]=2
	IF order[1] EQ 1 AND order[2] EQ 1 THEN shutter[a5-1]=3
	IF order[2] EQ 1 AND order[3] EQ 1 THEN shutter[a5-1]=4

	; Reconstruct the shutter order for band substitution eliminating M14 or M15 as sender. 
;	IF a5-1 NE 0 AND b EQ 4 AND shutter[a5-1] EQ -1 THEN BEGIN
;		IF change_order[a5-1] EQ 0 THEN shutter[a5-1]=shutter[a5-2]
;		IF change_order[a5-1] EQ 1 THEN BEGIN
;			IF shutter[a5-2] EQ 1 THEN shutter[a5-1]=3
;			IF shutter[a5-2] EQ 2 THEN shutter[a5-1]=1
;			IF shutter[a5-2] EQ 3 THEN shutter[a5-1]=4
;			IF shutter[a5-2] EQ 4 THEN shutter[a5-1]=2
;		ENDIF
;		IF change_order[a5-1] EQ 2 THEN BEGIN
;			IF shutter[a5-2] EQ 1 THEN shutter[a5-1]=4
;			IF shutter[a5-2] EQ 2 THEN shutter[a5-1]=3
;			IF shutter[a5-2] EQ 3 THEN shutter[a5-1]=2
;			IF shutter[a5-2] EQ 4 THEN shutter[a5-1]=1
;		ENDIF
;		IF change_order[a5-1] EQ 3 THEN BEGIN
;			IF shutter[a5-2] EQ 1 THEN shutter[a5-1]=2
;			IF shutter[a5-2] EQ 2 THEN shutter[a5-1]=4
;			IF shutter[a5-2] EQ 3 THEN shutter[a5-1]=1
;			IF shutter[a5-2] EQ 4 THEN shutter[a5-1]=3
;		ENDIF
;	ENDIF
;	print,'shutter=',shutter[a5-1],change_order[a5-1]


	; Reconstruct the shutter order for band substitution eliminating M16A as sender. 
;	x=0
;	y=0
;	IF b GE 3 AND a5-1 NE 0 THEN BEGIN
;		IF high_det[a5-1,1] EQ -1 THEN det=high_det[a5-2,1]
;		IF high_det[a5-1,1] NE -1 THEN det=high_det[a5-1,1]
;		loop:
;		FOR iscan=0, max_scan-1 DO BEGIN
;			print,a5-1,b,det,iscan,dn_frame_avg[0,det,0,iscan],dn_frame_avg[1,det,0,iscan]
;		ENDFOR
;		IF (dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,1]+ $
;			dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,1]) GT 1 THEN x=2
;		IF (dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,1]+ $
;			dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,1]) LT -1 THEN x=3
;		IF (dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,1]+ $
;			dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,1]) LT 1 AND $
;			(dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,1]+ $
;			dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,1]) GT -1 THEN BEGIN

;			IF (dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,2]+ $
;				dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,2]) GT 1 THEN x=1
;			IF (dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,2]+ $
;				dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,2]) LT -1 THEN x=4
;		ENDIF
;		IF abs(dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,2]+ $
;			dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,2]) LT 0.75 OR $
;			abs(dn_frame_avg[0,det,0,1]-dn_frame_avg[1,det,0,3]+ $
;			dn_frame_avg[1,det,0,1]-dn_frame_avg[0,det,0,3]) LT 0.75 THEN x=0
;		IF y EQ 1 THEN goto,out
;		IF x EQ 0 THEN BEGIN 
;			y=1
;			det=det-1
;			goto,loop
;		ENDIF
;		out:
;		print,'shutter=',shutter[a5-1],' x=',x
;		IF a5-1 NE 17 AND a5-1 NE 18 AND a5-1 NE 19 AND a5-1 NE 20 AND a5-1 NE 24 THEN shutter[a5-1]=x
;		IF a5-1 EQ 17 OR a5-1 EQ 18 OR a5-1 EQ 19 OR a5-1 EQ 20 OR a5-1 EQ 24 THEN BEGIN
;			IF (dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,2]+ $
;				dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,2]) GT 0.75 AND $
;				(dn_frame_avg[1,det,0,1]-dn_frame_avg[0,det,0,3]+ $
;				dn_frame_avg[0,det,0,1]-dn_frame_avg[1,det,0,3]) GT 1 THEN x=1
;			IF (dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,2]+ $
;				dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,2]) GT 1 AND $
;				(dn_frame_avg[1,det,0,1]-dn_frame_avg[0,det,0,3]+ $
;				dn_frame_avg[0,det,0,1]-dn_frame_avg[1,det,0,3]) LT -1 THEN x=2
;			IF (dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,2]+ $
;				dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,2]) LT -1 AND $
;				(dn_frame_avg[1,det,0,1]-dn_frame_avg[0,det,0,3]+ $
;				dn_frame_avg[0,det,0,1]-dn_frame_avg[1,det,0,3]) GT 1 THEN x=3
;			IF (dn_frame_avg[1,det,0,0]-dn_frame_avg[0,det,0,2]+ $
;				dn_frame_avg[0,det,0,0]-dn_frame_avg[1,det,0,2]) LT -1 AND $
;				(dn_frame_avg[1,det,0,1]-dn_frame_avg[0,det,0,3]+ $
;				dn_frame_avg[0,det,0,1]-dn_frame_avg[1,det,0,3]) LT -1 THEN x=4
;			shutter[a5-1]=x
;		ENDIF
;		print,'shutter=',shutter[a5-1],' x=',x
;	ENDIF

	IF b EQ 4 AND shutter[a5-1] EQ -1 THEN shutter[a5-1]=shutter[a5-2]

;*****************************************************************************
;  Write data to arrays that can be used later.
;*****************************************************************************

	band_info[a5-1,b,0]=max_det
	band_info[a5-1,b,1]=max_scan
	FOR iham=0, n_ham-1 DO BEGIN
		FOR idet=0, max_det-1 DO BEGIN
			FOR isubset=0, n_subset-1 DO BEGIN
				FOR iscan=0, max_scan-1 DO BEGIN
					dn_collect[a5-1,b,iham,idet,isubset,iscan]=dn_frame_avg[iham,idet,isubset,iscan]
					std_collect[a5-1,b,iham,idet,isubset,iscan]=std_frame_avg[iham,idet,isubset,iscan]
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

	skip:
ENDFOR

;*****************************************************************************
;  Average over scans and HAM side (since it is a staring test).
;*****************************************************************************

FOR collect=0, n_collects-1 DO BEGIN
	IF shutter[collect] EQ 1 THEN alpha=[1,1,-1,-1]
	IF shutter[collect] EQ 2 THEN alpha=[1,-1,-1,1]
	IF shutter[collect] EQ 3 THEN alpha=[-1,1,1,-1]
	IF shutter[collect] EQ 4 THEN alpha=[-1,-1,1,1]

	FOR b=0, n_bands-1 DO BEGIN
		m_det=band_info[collect,b,0]
		m_scan=band_info[collect,b,1]

		FOR idet=0, m_det-1 DO BEGIN
			FOR isubset=0, n_subset-1 DO BEGIN
				count=0
				FOR iscan=0, m_scan-4 DO BEGIN
					FOR iham=0, n_ham-1 DO BEGIN
						dn[collect,b,idet,isubset]=dn[collect,b,idet,isubset] $
							+alpha[0]*dn_collect[collect,b,iham,idet,isubset,iscan] $
							+alpha[1]*dn_collect[collect,b,iham,idet,isubset,iscan+1] $
							+alpha[2]*dn_collect[collect,b,iham,idet,isubset,iscan+2] $
							+alpha[3]*dn_collect[collect,b,iham,idet,isubset,iscan+3]

						std[collect,b,idet,isubset]=std[collect,b,idet,isubset] $
							+(1-alpha[0])/2*std_collect[collect,b,iham,idet,isubset,iscan] $
							+(1-alpha[1])/2*std_collect[collect,b,iham,idet,isubset,iscan+1] $
							+(1-alpha[2])/2*std_collect[collect,b,iham,idet,isubset,iscan+2] $
							+(1-alpha[3])/2*std_collect[collect,b,iham,idet,isubset,iscan+3]
					ENDFOR

					iscan=iscan+3
					count=count+2
					IF iscan EQ m_scan-1 THEN BEGIN
						dn[collect,b,idet,isubset]=dn[collect,b,idet,isubset]/count
						std[collect,b,idet,isubset]=std[collect,b,idet,isubset]/count
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
	save,/compress,high_det,dn,std,filename=outfile+'.dn.sav'
ENDFOR

;*****************************************************************************
;  Output DN to files for I and M bands.
;*****************************************************************************

fmt_1='(i3, 5x, a5, 5x, i2, 5x, d, 5x, d, 5x, d, 5x, d)'
fmt_2='(i3, 5x, a5, 5x, i2, 5x, d, 5x, d)'

; Output numbers to a data file.
openw,lun,outfile+'_I.dat',/get_lun
openw,lon,outfile+'_M.dat',/get_lun
printf,lun,'Collect  Band  Detector  DN(sub=0)    DN(sub=1)   STD(sub=0)    STD(sub=1)'
printf,lon,'Collect  Band  Detector  DN     STD'
FOR collect=0, n_collects-1 DO BEGIN
	FOR ib=0, 4 DO BEGIN
		ifile=6*collect+ib
		IF band_skip[ifile] EQ 1 THEN goto,skip_band
		FOR idet=0, 31 DO BEGIN
			IF ib EQ 0 THEN printf,lun,format=fmt_1,collect+1,bandname[0],idet+1, $
				dn[collect,0,idet,0],dn[collect,0,idet,1],std[collect,0,idet,0], $
				std[collect,0,idet,1]
			IF ib GT 0 AND idet EQ 16 THEN goto,skip_det
			IF ib GT 0 THEN printf,lon,format=fmt_2,collect+1,bandname[ib],idet+1, $
				dn[collect,ib,idet,0],std[collect,ib,idet,0]
		ENDFOR
		skip_det:
		skip_band:
	ENDFOR
ENDFOR
close,lun,/file,/all
free_lun,lun

;*****************************************************************************
;  Read gains from a file to an array.
;*****************************************************************************

openr,lun,'/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/gain_LWIR.dat',/get_lun

n_lines=File_Lines('/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/gain_LWIR.dat')
IF n_lines EQ 0 THEN goto,skipout

awa=''
b_name=strarr(n_lines)			; Band name.
ham_side=fltarr(n_lines)		; HAM side.
detector=fltarr(n_lines)		; detector.
subframe=fltarr(n_lines)		; BSubframe.
g=fltarr(n_lines)			; Gain.	

FOR ix=0L, n_lines-1 DO BEGIN
	readf,lun,awa
	a1=strsplit(awa,String(9B),/Extract)
	b_name(ix)=a1(0)
	ham_side(ix)=a1(2)-1
	detector(ix)=a1(3)-1
	subframe(ix)=a1(4)-1
	g(ix)=a1(6)
ENDFOR

close,lun,/file,/all
free_lun,lun

gain_temp=fltarr(n_bands,n_ham,32,n_subset)
gain=fltarr(n_bands,32,n_subset)
FOR i=0L, n_lines-1 DO BEGIN
	IF b_name[i] EQ 'I5' THEN BEGIN
		gain_temp[0,ham_side[i],detector[i],subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M14' THEN BEGIN
		gain_temp[1,ham_side[i],detector[i],subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M15' THEN BEGIN
		gain_temp[2,ham_side[i],detector[i],subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M16A' THEN BEGIN
		gain_temp[3,ham_side[i],detector[i],subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M16B' THEN BEGIN
		gain_temp[4,ham_side[i],detector[i],subframe[i]]=g[i]
	ENDIF
ENDFOR
gain[*,*,*]=(gain_temp[*,0,*,*]+gain_temp[*,1,*,*])/2

;*****************************************************************************
;  Calculate crosstalk parameters and write to an output file.
;*****************************************************************************

fmt='(i3, 5x, a5, 5x, i2, 5x, i2, 5x, a5, 5x, i2, 5x, i2, 5x, d, 5x, d, 5x, d, 5x, d, 5x, d)'

L_max=[15.429,17.561,17.107,14.502,14.502,0]
L_typ=[1.53,5.14,9.7,8.97,8.97,0]

XF_dn=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
XF_L=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
CNR=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
PVP=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
PVP_1=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
PVP_2=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)

openw,lun,outfile+'_coeff.dat',/get_lun
printf,lun,'Collect  S_Band  S_Detector  S_Subset  R_Band  R_Detector  R_Subset   XF_dn   XF_L   CNR   CNR_1   CNR_2'
FOR collect=0, n_collects-1 DO BEGIN

	; Sender band (s_band), ham (iham), detector (s_det), and subset (isubset).
	s_band=high_det[collect,0]
	s_det=fix(high_det[collect,1])

	IF s_band EQ 0 THEN n_subset=2
	IF s_band GT 0 THEN n_subset=1
	FOR isubset=0, n_subset-1 DO BEGIN

		; Receiver band (ib), ham (ih), detector (id), and subset (is).
		FOR ib=0, 4 DO BEGIN
			ifile_r=6*collect+ib
			IF band_skip[ifile_r] EQ 1 THEN goto,skip_band_r
			n_d=band_info[collect,ib,0]
			FOR id=0, n_d-1 DO BEGIN
				IF ib EQ 0 THEN n_subset=2
				IF ib GT 0 THEN n_subset=1
				FOR is=0, n_subset-1 DO BEGIN
					IF dn[collect,s_band,s_det,isubset] EQ 0 THEN BEGIN
						dn[collect,s_band,s_det,isubset]= $
							dn[collect-1,s_band,s_det,isubset]
					ENDIF
					dn_snd_band=total(dn[collect,s_band,*,isubset])

					XF_dn[collect,s_det,isubset,ib,id,is]= $
						dn[collect,ib,id,is]/dn_snd_band
					XF_L[collect,s_det,isubset,ib,id,is]= $
						gain[s_band,s_det,isubset]*dn[collect,ib,id,is]/ $
						(gain[ib,id,is]*dn_snd_band)

					PVP_1[collect,s_det,isubset,ib,id,is]= $
						2*sqrt(3)*L_max[s_band]*dn[collect,ib,id,is]*gain[s_band,s_det,isubset]/ $
						(dn_snd_band*std[collect,ib,id,is])
					PVP_2[collect,s_det,isubset,ib,id,is]= $
						L_max[s_band]*dn[collect,ib,id,is]*gain[s_band,s_det,isubset]/ $
						(dn_snd_band*gain[ib,id,is]*0.002*L_typ[ib])
					IF abs(PVP_2[collect,s_det,isubset,ib,id,is]) GT $
						abs(PVP_1[collect,s_det,isubset,ib,id,is]) THEN BEGIN
						PVP[collect,s_det,isubset,ib,id,is]=PVP_1[collect,s_det,isubset,ib,id,is]
					ENDIF ELSE BEGIN
						PVP[collect,s_det,isubset,ib,id,is]=PVP_2[collect,s_det,isubset,ib,id,is]
					ENDELSE
					CNR[collect,s_det,isubset,ib,id,is]=PVP_1[collect,s_det,isubset,ib,id,is]/4
					printf,lun,format=fmt,collect+1,bandname[s_band], $
						s_det+1,isubset,bandname[ib],id+1,is, $
						XF_dn[collect,s_det,isubset,ib,id,is], $
						XF_L[collect,s_det,isubset,ib,id,is], $
						CNR[collect,s_det,isubset,ib,id,is], $
						PVP[collect,s_det,isubset,ib,id,is]
				ENDFOR
			ENDFOR
			skip_band_r:
		ENDFOR
	ENDFOR
	save,/compress,gain,XF_dn,XF_L,CNR,PVP,filename=outfile+'.coeff.sav'
ENDFOR
close,lun,/file,/all
free_lun,lun

skipout:

END
