;*****************************************************************************
;				NICST TOOL
;
;  FP-13 Static LWIR Xtalk test. Reform XF_dn, XF_L, CNR, and PVP data to
;  fit into the point-to-point crosstalk table.
;  
;  v1.0 - 1/23/2008 - Jeff McIntire
;*****************************************************************************

PRO reform_LWIR

close,/all

band_name=['I5','M14','M15','M16A','M16B']
nband=n_elements(band_name)
ndet_I=32
ndet_M=16
det_I=findgen(ndet_I)
det_M=findgen(ndet_M)

uaidname=['3102128','3102155','3102157','3102159','3102161']
n_uaid=N_ELEMENTS(uaidname)
colnum=[34,33,33,64,32]

fmt='(i3, 5x, i3, 5x, i3, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13)'

FOR uaid=0, n_uaid-1 DO BEGIN

;*****************************************************************************
;  Create output files.
;*****************************************************************************

	outfname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.reform.coeff.dn.dat'
	outfname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.reform.coeff.L.dat'
	outfname3='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.reform.coeff.CNR.dat'
	outfname4='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.reform.coeff.PVP.dat'
	openw,lun,outfname1,/get_lun
	openw,lon,outfname2,/get_lun
	openw,len,outfname3,/get_lun
	openw,lin,outfname4,/get_lun
	printf,lun,'s_s  s_det  id  I5_SS1  I5_SS2  M16A  M16B  M15  M14'
	printf,lon,'s_s  s_det  id  I5_SS1  I5_SS2  M16A  M16B  M15  M14'
	printf,len,'s_s  s_det  id  I5_SS1  I5_SS2  M16A  M16B  M15  M14'
	printf,lin,'s_s  s_det  id  I5_SS1  I5_SS2  M16A  M16B  M15  M14'

;*****************************************************************************
;  Input data for I and M bands.
;*****************************************************************************

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.dn.sav'
;	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.snd_avg_coeff.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	restore,infname1
	restore,infname2

	XF_dn_I_r=fltarr(ndet_I,2,ndet_I,2)
	XF_L_I_r=fltarr(ndet_I,2,ndet_I,2)
	CNR_I_r=fltarr(ndet_I,2,ndet_I,2)
	PVP_I_r=fltarr(ndet_I,2,ndet_I,2)
	XF_dn_M_r=fltarr(ndet_I,2,4,ndet_I)
	XF_L_M_r=fltarr(ndet_I,2,4,ndet_I)
	CNR_M_r=fltarr(ndet_I,2,4,ndet_I)
	PVP_M_r=fltarr(ndet_I,2,4,ndet_I)

	XF_dn_I_t=fltarr(2,2)
	XF_L_I_t=fltarr(2,2)
	CNR_I_t=fltarr(2,2)
	PVP_I_t=fltarr(2,2)
	XF_dn_M_t=fltarr(2)
	XF_L_M_t=fltarr(2)
	CNR_M_t=fltarr(2)
	PVP_M_t=fltarr(2)

	count1=0
	count2=0
	FOR col=0, colnum[uaid]-1 DO BEGIN

		; U3102128
		IF uaid EQ 0 THEN BEGIN
			IF col EQ 0 OR col EQ 1 THEN goto,skip_col
		ENDIF
;		IF uaid EQ 0 THEN BEGIN
;			IF col EQ 0 OR col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
;				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 OR col EQ 23 $
;				OR col EQ 25 OR col EQ 27 OR col EQ 29 OR col EQ 31 OR col EQ 33 THEN goto,skip_col
;		ENDIF

		; U3102155
		IF uaid EQ 1 THEN BEGIN
			IF col EQ 10 THEN goto,skip_col
		ENDIF

		; U3102157
		IF uaid EQ 2 THEN BEGIN
			IF col EQ 0 THEN goto,skip_col
		ENDIF

		; U3102161
;		IF uaid EQ 4 THEN BEGIN
;			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 OR col EQ 13 $
;				OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 OR col EQ 23 OR col EQ 25 $
;				OR col EQ 27 OR col EQ 29 OR col EQ 31 THEN goto,skip_col
;		ENDIF

;*****************************************************************************
;  Reform data into appropriate format.
;*****************************************************************************

		band_lit=fix(high_det[col,0])
		det_lit=fix(high_det[col,1])

		XF_dn_I=fltarr(ndet_I,2,ndet_I,2)
		XF_L_I=fltarr(ndet_I,2,ndet_I,2)
		CNR_I=fltarr(ndet_I,2,ndet_I,2)
		PVP_I=fltarr(ndet_I,2,ndet_I,2)
		FOR i=0, ndet_I-1, 2 DO BEGIN
			XF_dn_I[*,*,i,0]=XF_dn[col,*,*,0,i,0]
			XF_dn_I[*,*,i+1,0]=XF_dn[col,*,*,0,i+1,1]
			XF_dn_I[*,*,i,1]=XF_dn[col,*,*,0,i,1]
			XF_dn_I[*,*,i+1,1]=XF_dn[col,*,*,0,i+1,0]

			XF_L_I[*,*,i,0]=XF_L[col,*,*,0,i,0]
			XF_L_I[*,*,i+1,0]=XF_L[col,*,*,0,i+1,1]
			XF_L_I[*,*,i,1]=XF_L[col,*,*,0,i,1]
			XF_L_I[*,*,i+1,1]=XF_L[col,*,*,0,i+1,0]

			CNR_I[*,*,i,0]=CNR[col,*,*,0,i,0]
			CNR_I[*,*,i+1,0]=CNR[col,*,*,0,i+1,1]
			CNR_I[*,*,i,1]=CNR[col,*,*,0,i,1]
			CNR_I[*,*,i+1,1]=CNR[col,*,*,0,i+1,0]

			PVP_I[*,*,i,0]=PVP[col,*,*,0,i,0]
			PVP_I[*,*,i+1,0]=PVP[col,*,*,0,i+1,1]
			PVP_I[*,*,i,1]=PVP[col,*,*,0,i,1]
			PVP_I[*,*,i+1,1]=PVP[col,*,*,0,i+1,0]
		ENDFOR

		XF_dn_M=(reform(XF_dn[col,*,*,1:4,0:15,0]))
		XF_L_M=(reform(XF_L[col,*,*,1:4,0:15,0]))
		CNR_M=(reform(CNR[col,*,*,1:4,0:15,0]))
		PVP_M=(reform(PVP[col,*,*,1:4,0:15,0]))

;*****************************************************************************
;  Reform I band data into appropriate format.
;*****************************************************************************

		IF band_lit EQ 0 THEN n_s=2
		IF band_lit NE 0 THEN n_s=1

		FOR s_s=0, n_s-1 DO BEGIN
			FOR r_s=0, 1 DO BEGIN
				FOR id=0, ndet_I-1 DO BEGIN
					XF_dn_I_r[det_lit,s_s,id,r_s]=XF_dn_I_r[det_lit,s_s,id,r_s]+XF_dn_I[det_lit,s_s,id,r_s]
					XF_L_I_r[det_lit,s_s,id,r_s]=XF_L_I_r[det_lit,s_s,id,r_s]+XF_L_I[det_lit,s_s,id,r_s]
					CNR_I_r[det_lit,s_s,id,r_s]=CNR_I_r[det_lit,s_s,id,r_s]+CNR_I[det_lit,s_s,id,r_s]
					PVP_I_r[det_lit,s_s,id,r_s]=PVP_I_r[det_lit,s_s,id,r_s]+PVP_I[det_lit,s_s,id,r_s]
				ENDFOR
			ENDFOR
		ENDFOR
		count1=count1+1
		IF count1 EQ 2 THEN BEGIN
			XF_dn_I_r[det_lit,*,*,*]=XF_dn_I_r[det_lit,*,*,*]/2
			XF_L_I_r[det_lit,*,*,*]=XF_L_I_r[det_lit,*,*,*]/2
			CNR_I_r[det_lit,*,*,*]=CNR_I_r[det_lit,*,*,*]/2
			PVP_I_r[det_lit,*,*,*]=PVP_I_r[det_lit,*,*,*]/2
			count1=0
		ENDIF

;*****************************************************************************
;  Include in-track correction for I bands.
;*****************************************************************************

		IF band_lit EQ 0 THEN BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				FOR r_s=0, 1 DO BEGIN
					XF_dn_I_t[s_s,r_s]=0
					XF_L_I_t[s_s,r_s]=0
					CNR_I_t[s_s,r_s]=0
					PVP_I_t[s_s,r_s]=0
				ENDFOR
			ENDFOR
			det_drop=4
			x1=det_lit-det_drop
			x2=det_lit+det_drop

			IF x1 LT 0 THEN BEGIN
				x1=-1 
				goto,skip_x1
			ENDIF
			FOR s_s=0, n_s-1 DO BEGIN
				FOR r_s=0, 1 DO BEGIN
					FOR i=0, x1 DO BEGIN
						XF_dn_I_t[s_s,r_s]=XF_dn_I_t[s_s,r_s]+XF_dn_I_r[det_lit,s_s,i,r_s]
						XF_L_I_t[s_s,r_s]=XF_L_I_t[s_s,r_s]+XF_L_I_r[det_lit,s_s,i,r_s]
						CNR_I_t[s_s,r_s]=CNR_I_t[s_s,r_s]+CNR_I_r[det_lit,s_s,i,r_s]
						PVP_I_t[s_s,r_s]=PVP_I_t[s_s,r_s]+PVP_I_r[det_lit,s_s,i,r_s]
					ENDFOR
				ENDFOR
			ENDFOR
			skip_x1:

			IF x2 GT 31 THEN BEGIN
				x2=32 
				goto,skip_x2
			ENDIF
			FOR s_s=0, n_s-1 DO BEGIN
				FOR r_s=0, 1 DO BEGIN
					FOR i=x2, 31 DO BEGIN
						XF_dn_I_t[s_s,r_s]=XF_dn_I_t[s_s,r_s]+XF_dn_I_r[det_lit,s_s,i,r_s]
						XF_L_I_t[s_s,r_s]=XF_L_I_t[s_s,r_s]+XF_L_I_r[det_lit,s_s,i,r_s]
						CNR_I_t[s_s,r_s]=CNR_I_t[s_s,r_s]+CNR_I_r[det_lit,s_s,i,r_s]
						PVP_I_t[s_s,r_s]=PVP_I_t[s_s,r_s]+PVP_I_r[det_lit,s_s,i,r_s]
					ENDFOR
				ENDFOR
			ENDFOR
			skip_x2:

			XF_dn_I_t[*,*]=XF_dn_I_t[*,*]/(x1+33-x2)
			XF_L_I_t[*,*]=XF_L_I_t[*,*]/(x1+33-x2)
			CNR_I_t[*,*]=CNR_I_t[*,*]/(x1+33-x2)
			PVP_I_t[*,*]=PVP_I_t[*,*]/(x1+33-x2)
			
			FOR i=x1+1, x2-1 DO BEGIN
				IF i EQ det_lit THEN goto,skip_high_1

				XF_dn_I_r[det_lit,*,i,*]=XF_dn_I_t[*,*]
				XF_L_I_r[det_lit,*,i,*]=XF_L_I_t[*,*]
				CNR_I_r[det_lit,*,i,*]=CNR_I_t[*,*]
				PVP_I_r[det_lit,*,i,*]=PVP_I_t[*,*]

				skip_high_1:
			ENDFOR
			
		ENDIF

;*****************************************************************************
;  Reform M band data into appropriate format.
;*****************************************************************************

		FOR ib=0, 3 DO BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				FOR id=0, ndet_I-1 DO BEGIN
					IF id LT 16 THEN BEGIN
						XF_dn_M_r[det_lit,s_s,ib,id]=XF_dn_M_r[det_lit,s_s,ib,id]+ $
							XF_dn_M[det_lit,s_s,ib,id]
						XF_L_M_r[det_lit,s_s,ib,id]=XF_L_M_r[det_lit,s_s,ib,id]+$
							XF_L_M[det_lit,s_s,ib,id]
						CNR_M_r[det_lit,s_s,ib,id]=CNR_M_r[det_lit,s_s,ib,id]+$
							CNR_M[det_lit,s_s,ib,id]
						PVP_M_r[det_lit,s_s,ib,id]=PVP_M_r[det_lit,s_s,ib,id]+$
							PVP_M[det_lit,s_s,ib,id]
					ENDIF ELSE BEGIN
						XF_dn_M_r[det_lit,s_s,ib,id]=-999
						XF_L_M_r[det_lit,s_s,ib,id]=-999
						CNR_M_r[det_lit,s_s,ib,id]=-999
						PVP_M_r[det_lit,s_s,ib,id]=-999
					ENDELSE
				ENDFOR
			ENDFOR
		ENDFOR
		count2=count2+1
		IF count2 EQ 2 THEN BEGIN
			XF_dn_M_r[det_lit,*,3,0:15]=XF_dn_M_r[det_lit,*,3,0:15]/2
			XF_L_M_r[det_lit,*,3,0:15]=XF_L_M_r[det_lit,*,3,0:15]/2
			CNR_M_r[det_lit,*,3,0:15]=CNR_M_r[det_lit,*,3,0:15]/2
			PVP_M_r[det_lit,*,3,0:15]=PVP_M_r[det_lit,*,3,0:15]/2
			count2=0
		ENDIF

;*****************************************************************************
;  Include in-track correction for M bands.
;*****************************************************************************

		IF band_lit NE 0 THEN BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				XF_dn_M_t[s_s]=0
				XF_L_M_t[s_s]=0
				CNR_M_t[s_s]=0
				PVP_M_t[s_s]=0
			ENDFOR

			IF uaid EQ 0 AND band_lit NE 1 THEN goto,skip_M14
			IF uaid EQ 1 AND band_lit NE 3 THEN goto,skip_M16A
			IF uaid EQ 2 AND band_lit NE 4 THEN goto,skip_M16B
			IF uaid EQ 4 AND band_lit NE 2 THEN goto,skip_M15

			IF uaid EQ 0 AND band_lit EQ 1 THEN det_drop=7
			IF uaid EQ 1 AND band_lit EQ 3 THEN det_drop=4
			IF uaid EQ 2 AND band_lit EQ 4 THEN det_drop=4
			IF uaid EQ 4 AND band_lit EQ 2 THEN det_drop=4

			x3=det_lit-det_drop
			x4=det_lit+det_drop

			IF x3 LT 0 THEN BEGIN
				x3=-1 
				goto,skip_x3
			ENDIF
			FOR s_s=0, n_s-1 DO BEGIN
				FOR i=0, x3 DO BEGIN
					XF_dn_M_t[s_s]=XF_dn_M_t[s_s]+XF_dn_M_r[det_lit,s_s,band_lit-1,i]
					XF_L_M_t[s_s]=XF_L_M_t[s_s]+XF_L_M_r[det_lit,s_s,band_lit-1,i]
					CNR_M_t[s_s]=CNR_M_t[s_s]+CNR_M_r[det_lit,s_s,band_lit-1,i]
					PVP_M_t[s_s]=PVP_M_t[s_s]+PVP_M_r[det_lit,s_s,band_lit-1,i]
				ENDFOR
			ENDFOR
			skip_x3:

			IF x4 GT 15 THEN BEGIN
				x4=16
				goto,skip_x4
			ENDIF
			FOR s_s=0, n_s-1 DO BEGIN
				FOR i=x4, 15 DO BEGIN
					XF_dn_M_t[s_s]=XF_dn_M_t[s_s]+XF_dn_M_r[det_lit,s_s,band_lit-1,i]
					XF_L_M_t[s_s]=XF_L_M_t[s_s]+XF_L_M_r[det_lit,s_s,band_lit-1,i]
					CNR_M_t[s_s]=CNR_M_t[s_s]+CNR_M_r[det_lit,s_s,band_lit-1,i]
					PVP_M_t[s_s]=PVP_M_t[s_s]+PVP_M_r[det_lit,s_s,band_lit-1,i]
				ENDFOR
			ENDFOR
			skip_x4:

			XF_dn_M_t[*]=XF_dn_M_t[*]/(x3+17-x4)
			XF_L_M_t[*]=XF_L_M_t[*]/(x3+17-x4)
			CNR_M_t[*]=CNR_M_t[*]/(x3+17-x4)
			PVP_M_t[*]=PVP_M_t[*]/(x3+17-x4)
			
			FOR i=x3+1, x4-1 DO BEGIN
				IF i EQ det_lit THEN goto,skip_high_2

				XF_dn_M_r[det_lit,*,band_lit-1,i]=XF_dn_M_t[*]
				XF_L_M_r[det_lit,*,band_lit-1,i]=XF_L_M_t[*]
				CNR_M_r[det_lit,*,band_lit-1,i]=CNR_M_t[*]
				PVP_M_r[det_lit,*,band_lit-1,i]=PVP_M_t[*]

				skip_high_2:
			ENDFOR

			skip_M14:
			skip_M15:
			skip_M16A:
			skip_M16B:
			
		ENDIF

		skip_col:
	ENDFOR

;*****************************************************************************
;  Display CNR that are above 1 (or below -1) and print to files.
;*****************************************************************************

	IF uaid EQ 3 THEN n_s=2
	IF uaid NE 3 THEN n_s=1
	IF uaid EQ 3 THEN n_det=32
	IF uaid NE 3 THEN n_det=16

	FOR s_s=0, n_s-1 DO BEGIN
		FOR r_s=0, 1 DO BEGIN
			FOR s_det=0, n_det-1 DO BEGIN
				FOR i=0, ndet_I-1 DO BEGIN
					IF abs(CNR_I_r[s_det,s_s,i,r_s]) GT 1 THEN print,'I',s_det+1,i+1,r_s 
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
	FOR s_s=0, n_s-1 DO BEGIN
		FOR ib=0, 3 DO BEGIN
			FOR s_det=0, n_det-1 DO BEGIN
				FOR i=0, ndet_M-1 DO BEGIN
					IF abs(CNR_M_r[s_det,s_s,ib,i]) GT 1 THEN print,'M',s_det+1,ib,i+1
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

	FOR s_s=0, n_s-1 DO BEGIN
		FOR s_det=0, n_det-1 DO BEGIN
			FOR id=0, ndet_I-1 DO BEGIN
				printf,lun,s_s+1,s_det+1,id+1,XF_dn_I_r[s_det,s_s,id,0],XF_dn_I_r[s_det,s_s,id,1], $
					XF_dn_M_r[s_det,s_s,2,id],XF_dn_M_r[s_det,s_s,3,id],XF_dn_M_r[s_det,s_s,1,id], $
					XF_dn_M_r[s_det,s_s,0,id],format=fmt
				printf,lon,s_s+1,s_det+1,id+1,XF_L_I_r[s_det,s_s,id,0],XF_L_I_r[s_det,s_s,id,1], $
					XF_L_M_r[s_det,s_s,2,id],XF_L_M_r[s_det,s_s,3,id],XF_L_M_r[s_det,s_s,1,id], $
					XF_L_M_r[s_det,s_s,0,id],format=fmt
				printf,len,s_s+1,s_det+1,id+1,CNR_I_r[s_det,s_s,id,0],CNR_I_r[s_det,s_s,id,1], $
					CNR_M_r[s_det,s_s,2,id],CNR_M_r[s_det,s_s,3,id],CNR_M_r[s_det,s_s,1,id], $
					CNR_M_r[s_det,s_s,0,id],format=fmt
				printf,lin,s_s+1,s_det+1,id+1,PVP_I_r[s_det,s_s,id,0],PVP_I_r[s_det,s_s,id,1], $
					PVP_M_r[s_det,s_s,2,id],PVP_M_r[s_det,s_s,3,id],PVP_M_r[s_det,s_s,1,id], $
					PVP_M_r[s_det,s_s,0,id],format=fmt
			ENDFOR
		ENDFOR
	ENDFOR
	save,/compress,XF_dn_I_r,XF_dn_M_r,XF_L_I_r,XF_L_M_r,CNR_I_r,CNR_M_r,PVP_I_r,PVP_M_r, $
		filename='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.reform.sav'

	skip_loop:
ENDFOR

close,/all

END
