;*****************************************************************************
;				NICST TOOL
;
;  Graphs dn and three influence coefficients as a function of detectors and
;  also in focal plane order.
;  
;  v1.0 - 10/7/2007 - Chunhui Pan
;  v2.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO view_sf_LWIR

close,/all

band_name=['I5 SS1','I5 SS2','M14','M15','M16A','M16B']
ibindx=[0]
n_gain=[0,0,0,0,0]
nband=n_elements(band_name)
ndet_I=32
ndet_M=16
det_I=findgen(ndet_I)
det_M=findgen(ndet_M)

i=0
ibdet2=fltarr(32)
FOR x=0,ndet_I-1 DO BEGIN
    ibdet2[i]=float(x)/2+1.0
    i=i+1
ENDFOR

uaidname=['3102128','3102155','3102157','3102159','3102161']
n_uaid=N_ELEMENTS(uaidname)
colnum=[34,33,33,64,32]
tick_name=[' ','I5 SS1','I5 SS2','M16A','M16B','M15','M14',' ']

;*****************************************************************************
;  Read in data, skip bad collects, and reform data.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN
	set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
	set_plot,'ps'
	outfname='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.ps'
	device,/landscape,filename=outfname,/color
	!p.multi=[0,2,2]

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.d.sav'
;	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.snd_avg_coeff.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	restore,infname1
	restore,infname2

	FOR col=0, colnum[uaid]-1 DO BEGIN

		; U3102128
		IF uaidname[uaid] EQ '3102128' THEN BEGIN
			IF col EQ 0 OR col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 $
				OR col EQ 11 OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 $
				OR col EQ 21 OR col EQ 23 OR col EQ 25 OR col EQ 27 OR col EQ 29 $ 
				OR col EQ 31 OR col EQ 33 THEN goto,skip_col
		ENDIF

		IF uaidname[uaid] EQ '3102155' THEN BEGIN
			IF col EQ 10 THEN goto,skip_col
		ENDIF

		; U3102157
		IF uaidname[uaid] EQ '3102157' THEN BEGIN
			IF col EQ 0 THEN goto,skip_col
		ENDIF

		; U3102161
		IF uaidname[uaid] EQ '3102161' THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 $
				OR col EQ 23 OR col EQ 25 OR col EQ 27 OR col EQ 29 OR col EQ 31 $
				THEN goto,skip_col
		ENDIF

		det_lit=fix(high_det[col,1])

		dn_I=fltarr(ndet_I,2)
		XF_dn_I=fltarr(ndet_I,2,ndet_I,2)
		XF_L_I=fltarr(ndet_I,2,ndet_I,2)
		CNR_I=fltarr(ndet_I,2,ndet_I,2)
		FOR i=0, ndet_I-1, 2 DO BEGIN
			dn_I[i,0]=dn[col,0,i,0]
			dn_I[i+1,0]=dn[col,0,i+1,1]
			dn_I[i,1]=dn[col,0,i,1]
			dn_I[i+1,1]=dn[col,0,i+1,0]

			XF_dn_I[*,*,i,0]=XF_dn[col,*,*,0,i,0]*1000
			XF_dn_I[*,*,i+1,0]=XF_dn[col,*,*,0,i+1,1]*1000
			XF_dn_I[*,*,i,1]=XF_dn[col,*,*,0,i,1]*1000
			XF_dn_I[*,*,i+1,1]=XF_dn[col,*,*,0,i+1,0]*1000

			XF_L_I[*,*,i,0]=XF_L[col,*,*,0,i,0]*1000
			XF_L_I[*,*,i+1,0]=XF_L[col,*,*,0,i+1,1]*1000
			XF_L_I[*,*,i,1]=XF_L[col,*,*,0,i,1]*1000
			XF_L_I[*,*,i+1,1]=XF_L[col,*,*,0,i+1,0]*1000

			CNR_I[*,*,i,0]=CNR[col,*,*,0,i,0]
			CNR_I[*,*,i+1,0]=CNR[col,*,*,0,i+1,1]
			CNR_I[*,*,i,1]=CNR[col,*,*,0,i,1]
			CNR_I[*,*,i+1,1]=CNR[col,*,*,0,i+1,0]
		ENDFOR

		dn_M=(reform(dn[col,1:4,*,0]))
		XF_dn_M=(reform(XF_dn[col,*,*,1:4,*,0]))*1000
		XF_L_M=(reform(XF_L[col,*,*,1:4,*,0]))*1000
		CNR_M=(reform(CNR[col,*,*,1:4,*,0]))

		flag=fltarr(4)
		FOR ib=0, 3 DO BEGIN
			IF mean(dn_M[ib,*]) EQ 0 THEN flag[ib]=1
		ENDFOR

		ymin_1=min(dn_I[*,0])
		ymin_2=min(dn_M[*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		ymax_1=max(dn_I[*,0])
		ymax_2=max(dn_M[*,*])
		IF ymax_1 GE ymax_2 THEN ymax=ymax_1
		IF ymax_1 LT ymax_2 THEN ymax=ymax_2

		; Plot dn per detector on a log plot.
		!P.thick=5

		plot,ibdet2[*],dn_I[*,0],xrange=[0,ndet_M+1],yrange=[0.0001,ymax],ytit='dn',xtit='detector', $
			charsize=1.2,charthick=5,/nodata,/ylog
		oplot,ibdet2[*],dn_I[*,0],symsize=1,color=lcol[0],psym=symbol[0]
		oplot,ibdet2[*],dn_I[*,0],color=lcol[0]
		oplot,ibdet2[*],dn_I[*,1],symsize=1,color=lcol[1],psym=symbol[1]
		oplot,ibdet2[*],dn_I[*,1],color=lcol[1]
		FOR ib=0, 3 DO BEGIN
			IF flag[ib] EQ 1 THEN goto,skip_band_1
			oplot,det_M[0:15]+1,dn_M[ib,0:15],symsize=1,color=lcol[ib+2],psym=symbol[ib+2]
			oplot,det_M[0:15]+1,dn_M[ib,0:15],color=lcol[ib+2]
			skip_band_1:
		ENDFOR

		; Plot dn per detector.

		ymax=5

		plot,ibdet2[*],dn_M[0,*],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='dn',xtit='detector', $
			charsize=1.2,charthick=5,/nodata
		oplot,ibdet2[*],dn_I[*,0],symsize=1,color=lcol[0],psym=symbol[0]
		oplot,ibdet2[*],dn_I[*,0],color=lcol[0]
		oplot,ibdet2[*],dn_I[*,1],symsize=1,color=lcol[1],psym=symbol[1]
		oplot,ibdet2[*],dn_I[*,1],color=lcol[1]
		FOR ib=0, 3 DO BEGIN
			IF flag[ib] EQ 1 THEN goto,skip_band_2
			oplot,det_M[0:15]+1,dn_M[ib,0:15],symsize=1,color=lcol[ib+2],psym=symbol[ib+2]
			oplot,det_M[0:15]+1,dn_M[ib,0:15],color=lcol[ib+2]
			skip_band_2:
		ENDFOR

		; Plot XF_dn per detector.

		ymax=2
		ymin_1=min(XF_dn_I[det_lit,0,*,0])
		ymin_2=min(XF_dn_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],XF_dn_I[det_lit,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='XF_dn*1000', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		oplot,ibdet2[*],XF_dn_I[det_lit,0,*,0],symsize=1,color=lcol[0],psym=symbol[0]
		oplot,ibdet2[*],XF_dn_I[det_lit,0,*,0],color=lcol[0]
		oplot,ibdet2[*],XF_dn_I[det_lit,0,*,1],symsize=1,color=lcol[1],psym=symbol[1]
		oplot,ibdet2[*],XF_dn_I[det_lit,0,*,1],color=lcol[1]
		FOR ib=0, 3 DO BEGIN
			IF flag[ib] EQ 1 THEN goto,skip_band_3
			oplot,det_M[0:15]+1,XF_dn_M[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+2],psym=symbol[ib+2]
			oplot,det_M[0:15]+1,XF_dn_M[det_lit,0,ib,0:15],color=lcol[ib+2]
			skip_band_3:
		ENDFOR

		; Plot XF_L per detector.

		ymax=2
		ymin_1=min(XF_L_I[det_lit,0,*,0])
		ymin_2=min(XF_L_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],XF_L_I[det_lit,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='XF_L*1000', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		oplot,ibdet2[*],XF_L_I[det_lit,0,*,0],symsize=1,color=lcol[0],psym=symbol[0]
		oplot,ibdet2[*],XF_L_I[det_lit,0,*,0],color=lcol[0]
		oplot,ibdet2[*],XF_L_I[det_lit,0,*,1],symsize=1,color=lcol[1],psym=symbol[1]
		oplot,ibdet2[*],XF_L_I[det_lit,0,*,1],color=lcol[1]
		FOR ib=0, 3 DO BEGIN
			IF flag[ib] EQ 1 THEN goto,skip_band_4
			oplot,det_M[0:15]+1,XF_L_M[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+2],psym=symbol[ib+2]
			oplot,det_M[0:15]+1,XF_L_M[det_lit,0,ib,0:15],color=lcol[ib+2]
			skip_band_4:
		ENDFOR

		IF uaidname[uaid] EQ '3102159' THEN BEGIN
			title='U'+uaidname[uaid]+' Collect '+strtrim(string(col+1),2)+': Illuminated Band '+ $
				strtrim(band_name[fix(high_det[col,0])],2)+', Detecter '+ $
				strtrim(string(fix(high_det[col,1]+1)),2)
		ENDIF ELSE BEGIN
			title='U'+uaidname[uaid]+' Collect '+strtrim(string(col+1),2)+': Illuminated Band '+ $
				strtrim(band_name[fix(high_det[col,0]+1)],2)+', Detecter '+ $
				strtrim(string(fix(high_det[col,1]+1)),2)
		ENDELSE
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		set_legend,1,band_name,lcol,symbol
		!p.multi=[0,2,2]
		!p.position=0

		; Plot dn per band.

		bandindex_1=findgen(6)+1
		bandindex_2=WHERE(bandindex_1 NE 3)+1

		ymax=2
		ymin_1=min(dn_I[*,0])
		ymin_2=min(dn_M[*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,7],xstyle=1,yrange=[ymin,ymax],ytit='dn',/nodata,XTICKS=7,XTICKN=tick_name, $
			charsize=1.2,charthick=5
		FOR iii=1, 6 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				IF flag[1] EQ 1 THEN BEGIN
					oplot,bandindex_1,[dn_I[idet,0],dn_I[idet,1],dn_M[2,idet],dn_M[3,idet]], $
						symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_1,[dn_I[idet,0],dn_I[idet,1],dn_M[2,idet],dn_M[3,idet]], $
						color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[dn_I[idet,0],dn_I[idet,1],dn_M[3,idet],dn_M[1,idet], $
						dn_M[0,idet]],symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[dn_I[idet,0],dn_I[idet,1],dn_M[3,idet],dn_M[1,idet], $
						dn_M[0,idet]],color=lcol[idet]
				ENDIF
			ENDIF ELSE BEGIN
				oplot,bandindex_1,[dn_I[idet,0],dn_I[idet,1]],symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[dn_I[idet,0],dn_I[idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot XF_dn per band.

		ymax=2
		ymin_1=min(XF_dn_I[det_lit,0,*,0])
		ymin_2=min(XF_dn_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,7],xstyle=1,yrange=[ymin,ymax],ytit='XF_dn*1000',/nodata,XTICKS=7,XTICKN=tick_name, $
			charsize=1.2,charthick=5
		FOR iii=1, 6 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				IF flag[1] EQ 1 THEN BEGIN
					oplot,bandindex_1,[XF_dn_I[det_lit,0,idet,0],XF_dn_I[det_lit,0,idet,1], $
						XF_dn_M[det_lit,0,2,idet],XF_dn_M[det_lit,0,3,idet]], $
						symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_1,[XF_dn_I[det_lit,0,idet,0],XF_dn_I[det_lit,0,idet,1], $
						XF_dn_M[det_lit,0,2,idet],XF_dn_M[det_lit,0,3,idet]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[XF_dn_I[det_lit,0,idet,0],XF_dn_I[det_lit,0,idet,1], $
						XF_dn_M[det_lit,0,3,idet],XF_dn_M[det_lit,0,1,idet], $
						XF_dn_M[det_lit,0,0,idet]],symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[XF_dn_I[det_lit,0,idet,0],XF_dn_I[det_lit,0,idet,1], $
						XF_dn_M[det_lit,0,3,idet],XF_dn_M[det_lit,0,1,idet], $
						XF_dn_M[det_lit,0,0,idet]],color=lcol[idet]
				ENDIF
			ENDIF ELSE BEGIN
				oplot,bandindex_1,[XF_dn_I[det_lit,0,idet,0],XF_dn_I[det_lit,0,idet,1]], $
					symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[XF_dn_I[det_lit,0,idet,0],XF_dn_I[det_lit,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot XF_L per band.

		ymax=2
		ymin_1=min(XF_L_I[det_lit,0,*,0])
		ymin_2=min(XF_L_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,7],xstyle=1,yrange=[ymin,ymax],ytit='XF_L*1000',/nodata,XTICKS=7,XTICKN=tick_name, $
			charsize=1.2,charthick=5
		FOR iii=1, 6 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				IF flag[1] EQ 1 THEN BEGIN
					oplot,bandindex_1,[XF_L_I[det_lit,0,idet,0],XF_L_I[det_lit,0,idet,1], $
						XF_L_M[det_lit,0,2,idet],XF_L_M[det_lit,0,3,idet]], $
						symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_1,[XF_L_I[det_lit,0,idet,0],XF_L_I[det_lit,0,idet,1], $
						XF_L_M[det_lit,0,2,idet],XF_L_M[det_lit,0,3,idet]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[XF_L_I[det_lit,0,idet,0],XF_L_I[det_lit,0,idet,1], $
						XF_L_M[det_lit,0,3,idet],XF_L_M[det_lit,0,1,idet], $
						XF_L_M[det_lit,0,0,idet]],symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[XF_L_I[det_lit,0,idet,0],XF_L_I[det_lit,0,idet,1], $
						XF_L_M[det_lit,0,3,idet],XF_L_M[det_lit,0,1,idet], $
						XF_L_M[det_lit,0,0,idet]],color=lcol[idet]
				ENDIF
			ENDIF ELSE BEGIN
				oplot,bandindex_1,[XF_L_I[det_lit,0,idet,0],XF_L_I[det_lit,0,idet,1]], $
					symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[XF_L_I[det_lit,0,idet,0],XF_L_I[det_lit,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot CNR per band.

		ymax=1
		ymin_1=min(CNR_I[det_lit,0,*,0])
		ymin_2=min(CNR_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,7],xstyle=1,yrange=[ymin,ymax],ytit='CNR',/nodata,XTICKS=7,XTICKN=tick_name, $
			charsize=1.2,charthick=5
		FOR iii=1, 6 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				IF flag[1] EQ 1 THEN BEGIN
					oplot,bandindex_1,[CNR_I[det_lit,0,idet,0],CNR_I[det_lit,0,idet,1], $
						CNR_M[det_lit,0,2,idet],CNR_M[det_lit,0,3,idet]], $
						symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_1,[CNR_I[det_lit,0,idet,0],CNR_I[det_lit,0,idet,1], $
						CNR_M[det_lit,0,2,idet],CNR_M[det_lit,0,3,idet]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[CNR_I[det_lit,0,idet,0],CNR_I[det_lit,0,idet,1], $
						CNR_M[det_lit,0,3,idet],CNR_M[det_lit,0,1,idet],CNR_M[det_lit,0,0,idet]], $
						symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[CNR_I[det_lit,0,idet,0],CNR_I[det_lit,0,idet,1], $
						CNR_M[det_lit,0,3,idet],CNR_M[det_lit,0,1,idet], $
						CNR_M[det_lit,0,0,idet]],color=lcol[idet]
				ENDIF
			ENDIF ELSE BEGIN
				oplot,bandindex_1,[CNR_I[det_lit,0,idet,0],CNR_I[det_lit,0,idet,1]], $
					symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[CNR_I[det_lit,0,idet,0],CNR_I[det_lit,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		IF uaidname[uaid] EQ '3102159' THEN BEGIN
			title='U'+uaidname[uaid]+' Collect '+strtrim(string(col+1),2)+': Illuminated Band '+ $
				strtrim(band_name[fix(high_det[col,0])],2)+', Detecter '+ $
				strtrim(string(fix(high_det[col,1]+1)),2)
		ENDIF ELSE BEGIN
			title='U'+uaidname[uaid]+' Collect '+strtrim(string(col+1),2)+': Illuminated Band '+ $
				strtrim(band_name[fix(high_det[col,0]+1)],2)+', Detecter '+ $
				strtrim(string(fix(high_det[col,1]+1)),2)
		ENDELSE
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		set_legend,2,chname,lcol,symbol
		!p.multi=[0,2,2]
		!p.position=0
	
		skip_col:
	ENDFOR 	;col

	skip_loop:
ENDFOR 	;uaid
device,/close

!p.multi=0
!p.position=0

END
