;*****************************************************************************
;				NICST TOOL
;
;  Graphs three influence coefficients and PVP as a function of detectors and
;  also in focal plane order.
;  
;  v1.0 - 10/7/2007 - Chunhui Pan
;  v2.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO view_sf_LWIR_2

close,/all

band_name=['I5 SS1','I5 SS2','M14','M15','M16A','M16B']
name_band=['I5','M14','M15','M16A','M16B']
ibindx=[0]
n_gain=[0,0,0,0,0]
nband=n_elements(band_name)
ndet_I=32
ndet_M=16
det_I=findgen(ndet_I)
det_M=findgen(ndet_M)

i=0
ibdet2=fltarr(32)
FOR x=0,ndet_I-1 DO BEGIN
    ibdet2[i]=float(x)/2+1.0
    i=i+1
ENDFOR

uaidname=['3102128','3102155','3102157','3102159','3102161']
n_uaid=N_ELEMENTS(uaidname)
colnum=[34,33,33,64,32]
tick_name=[' ','I5_1','I5_2','M16A','M16B','M15','M14',' ']

;*****************************************************************************
;  Read in data.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN
	set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
	set_plot,'ps'
	outfname='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.2.ps'
	device,/landscape,filename=outfname,/color
	!p.multi=[0,2,2]

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.dn.sav'
;	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.sav'
;	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.snd_avg_coeff.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/LWIR/U'+uaidname[uaid]+'.coeff.reform.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	restore,infname1
	restore,infname2

	XF_dn_I_r[*,*,*,*]=XF_dn_I_r[*,*,*,*]*1000
	XF_L_I_r[*,*,*,*]=XF_L_I_r[*,*,*,*]*1000
	XF_dn_M_r[*,*,*,*]=XF_dn_M_r[*,*,*,*]*1000
	XF_L_M_r[*,*,*,*]=XF_L_M_r[*,*,*,*]*1000

	IF uaid NE 3 THEN ndet=ndet_M
	IF uaid EQ 3 THEN ndet=ndet_I

	FOR det_lit=0, ndet-1 DO BEGIN

		bandindex=findgen(6)+1
		bandindex_1=findgen(6)+1
		bandindex_2=WHERE(bandindex_1 NE 3)+1

		; Plot XF_dn per detector.

		ymax=2
		ymin_1=min(XF_dn_I_r[det_lit,0,*,0])
		ymin_2=min(XF_dn_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],XF_dn_I_r[det_lit,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='XF_dn*1000', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		oplot,ibdet2[*],XF_dn_I_r[det_lit,0,*,0],symsize=1,color=lcol[0],psym=symbol[0]
		oplot,ibdet2[*],XF_dn_I_r[det_lit,0,*,0],color=lcol[0]
		oplot,ibdet2[*],XF_dn_I_r[det_lit,0,*,1],symsize=1,color=lcol[1],psym=symbol[1]
		oplot,ibdet2[*],XF_dn_I_r[det_lit,0,*,1],color=lcol[1]
		FOR ib=0, 3 DO BEGIN
			oplot,det_M[0:15]+1,XF_dn_M_r[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+2],psym=symbol[ib+2]
			oplot,det_M[0:15]+1,XF_dn_M_r[det_lit,0,ib,0:15],color=lcol[ib+2]
		ENDFOR

		; Plot XF_L per detector.

		ymax=2
		ymin_1=min(XF_L_I_r[det_lit,0,*,0])
		ymin_2=min(XF_L_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],XF_L_I_r[det_lit,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='XF_L*1000', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		oplot,ibdet2[*],XF_L_I_r[det_lit,0,*,0],symsize=1,color=lcol[0],psym=symbol[0]
		oplot,ibdet2[*],XF_L_I_r[det_lit,0,*,0],color=lcol[0]
		oplot,ibdet2[*],XF_L_I_r[det_lit,0,*,1],symsize=1,color=lcol[1],psym=symbol[1]
		oplot,ibdet2[*],XF_L_I_r[det_lit,0,*,1],color=lcol[1]
		FOR ib=0, 3 DO BEGIN
			oplot,det_M[0:15]+1,XF_L_M_r[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+2],psym=symbol[ib+2]
			oplot,det_M[0:15]+1,XF_L_M_r[det_lit,0,ib,0:15],color=lcol[ib+2]
		ENDFOR

		; Plot CNR per detector.

		ymax=2
		ymin_1=min(CNR_I_r[det_lit,0,*,0])
		ymin_2=min(CNR_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],CNR_I_r[det_lit,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='CNR', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		oplot,ibdet2[*],CNR_I_r[det_lit,0,*,0],symsize=1,color=lcol[0],psym=symbol[0]
		oplot,ibdet2[*],CNR_I_r[det_lit,0,*,0],color=lcol[0]
		oplot,ibdet2[*],CNR_I_r[det_lit,0,*,1],symsize=1,color=lcol[1],psym=symbol[1]
		oplot,ibdet2[*],CNR_I_r[det_lit,0,*,1],color=lcol[1]
		FOR ib=0, 3 DO BEGIN
			oplot,det_M[0:15]+1,CNR_M_r[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+2],psym=symbol[ib+2]
			oplot,det_M[0:15]+1,CNR_M_r[det_lit,0,ib,0:15],color=lcol[ib+2]
		ENDFOR

		; Plot PVP per detector.

		ymax=2
		ymin_1=min(PVP_I_r[det_lit,0,*,0])
		ymin_2=min(PVP_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],PVP_I_r[det_lit,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='PVP', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		oplot,ibdet2[*],PVP_I_r[det_lit,0,*,0],symsize=1,color=lcol[0],psym=symbol[0]
		oplot,ibdet2[*],PVP_I_r[det_lit,0,*,0],color=lcol[0]
		oplot,ibdet2[*],PVP_I_r[det_lit,0,*,1],symsize=1,color=lcol[1],psym=symbol[1]
		oplot,ibdet2[*],PVP_I_r[det_lit,0,*,1],color=lcol[1]
		FOR ib=0, 3 DO BEGIN
			oplot,det_M[0:15]+1,PVP_M_r[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+2],psym=symbol[ib+2]
			oplot,det_M[0:15]+1,PVP_M_r[det_lit,0,ib,0:15],color=lcol[ib+2]
		ENDFOR

		IF uaid EQ 0 THEN band=name_band[1]
		IF uaid EQ 1 THEN band=name_band[3]
		IF uaid EQ 2 THEN band=name_band[4]
		IF uaid EQ 3 THEN band=name_band[0]
		IF uaid EQ 4 THEN band=name_band[2]

		title='U'+uaidname[uaid]+': Sender Band '+strtrim(band,2)+', Detecter '+ $
			strtrim(string(fix(det_lit+1)),2)
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		set_legend,1,band_name,lcol,symbol
		!p.multi=[0,2,2]
		!p.position=0

		; Plot XF_dn per band.

		ymax=2
		ymin_1=min(XF_dn_I_r[det_lit,0,*,0])
		ymin_2=min(XF_dn_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,7],xstyle=1,yrange=[ymin,ymax],ytit='XF_dn*1000',/nodata,XTICKS=7,XTICKN=tick_name, $
			charsize=1.1,charthick=5
		FOR iii=1, 6 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				oplot,bandindex,[XF_dn_I_r[det_lit,0,idet,0],XF_dn_I_r[det_lit,0,idet,1], $
					XF_dn_M_r[det_lit,0,2,idet],XF_dn_M_r[det_lit,0,3,idet],XF_dn_M_r[det_lit,0,1,idet], $
					XF_dn_M_r[det_lit,0,0,idet]],symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex,[XF_dn_I_r[det_lit,0,idet,0],XF_dn_I_r[det_lit,0,idet,1], $
					XF_dn_M_r[det_lit,0,2,idet],XF_dn_M_r[det_lit,0,3,idet],XF_dn_M_r[det_lit,0,1,idet], $
					XF_dn_M_r[det_lit,0,0,idet]],color=lcol[idet]
			ENDIF ELSE BEGIN
				oplot,bandindex_1,[XF_dn_I_r[det_lit,0,idet,0],XF_dn_I_r[det_lit,0,idet,1]], $
					symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[XF_dn_I_r[det_lit,0,idet,0],XF_dn_I_r[det_lit,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot XF_L per band.

		ymax=2
		ymin_1=min(XF_L_I_r[det_lit,0,*,0])
		ymin_2=min(XF_L_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,7],xstyle=1,yrange=[ymin,ymax],ytit='XF_L*1000',/nodata,XTICKS=7,XTICKN=tick_name, $
			charsize=1.1,charthick=5
		FOR iii=1, 6 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				oplot,bandindex,[XF_L_I_r[det_lit,0,idet,0],XF_L_I_r[det_lit,0,idet,1], $
					XF_L_M_r[det_lit,0,2,idet],XF_L_M_r[det_lit,0,3,idet],XF_L_M_r[det_lit,0,1,idet], $
					XF_L_M_r[det_lit,0,0,idet]],symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex,[XF_L_I_r[det_lit,0,idet,0],XF_L_I_r[det_lit,0,idet,1], $
					XF_L_M_r[det_lit,0,2,idet],XF_L_M_r[det_lit,0,3,idet],XF_L_M_r[det_lit,0,1,idet], $
					XF_L_M_r[det_lit,0,0,idet]],color=lcol[idet]
			ENDIF ELSE BEGIN
				oplot,bandindex_1,[XF_L_I_r[det_lit,0,idet,0],XF_L_I_r[det_lit,0,idet,1]], $
					symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[XF_L_I_r[det_lit,0,idet,0],XF_L_I_r[det_lit,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot CNR per band.

		ymax=2
		ymin_1=min(CNR_I_r[det_lit,0,*,0])
		ymin_2=min(CNR_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,7],xstyle=1,yrange=[ymin,ymax],ytit='CNR',/nodata,XTICKS=7,XTICKN=tick_name, $
			charsize=1.1,charthick=5
		FOR iii=1, 6 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				oplot,bandindex,[CNR_I_r[det_lit,0,idet,0],CNR_I_r[det_lit,0,idet,1], $
					CNR_M_r[det_lit,0,2,idet],CNR_M_r[det_lit,0,3,idet],CNR_M_r[det_lit,0,1,idet], $
					CNR_M_r[det_lit,0,0,idet]],symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex,[CNR_I_r[det_lit,0,idet,0],CNR_I_r[det_lit,0,idet,1], $
					CNR_M_r[det_lit,0,2,idet],CNR_M_r[det_lit,0,3,idet],CNR_M_r[det_lit,0,1,idet], $
					CNR_M_r[det_lit,0,0,idet]],color=lcol[idet]

			ENDIF ELSE BEGIN
				oplot,bandindex_1,[CNR_I_r[det_lit,0,idet,0],CNR_I_r[det_lit,0,idet,1]], $
					symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[CNR_I_r[det_lit,0,idet,0],CNR_I_r[det_lit,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot PVP per band.

		ymax=2
		ymin_1=min(PVP_I_r[det_lit,0,*,0])
		ymin_2=min(PVP_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,7],xstyle=1,yrange=[ymin,ymax],ytit='PVP',/nodata,XTICKS=7,XTICKN=tick_name, $
			charsize=1.1,charthick=5
		FOR iii=1, 6 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				oplot,bandindex,[PVP_I_r[det_lit,0,idet,0],PVP_I_r[det_lit,0,idet,1], $
					PVP_M_r[det_lit,0,2,idet],PVP_M_r[det_lit,0,3,idet],PVP_M_r[det_lit,0,1,idet], $
					PVP_M_r[det_lit,0,0,idet]],symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex,[PVP_I_r[det_lit,0,idet,0],PVP_I_r[det_lit,0,idet,1], $
					PVP_M_r[det_lit,0,2,idet],PVP_M_r[det_lit,0,3,idet],PVP_M_r[det_lit,0,1,idet], $
					PVP_M_r[det_lit,0,0,idet]],color=lcol[idet]

			ENDIF ELSE BEGIN
				oplot,bandindex_1,[PVP_I_r[det_lit,0,idet,0],PVP_I_r[det_lit,0,idet,1]], $
					symsize=1,color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[PVP_I_r[det_lit,0,idet,0],PVP_I_r[det_lit,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
		set_legend,2,chname,lcol,symbol
		!p.multi=[0,2,2]
		!p.position=0
	
		skip_col:
	ENDFOR

	skip_loop:
ENDFOR 	;uaid
device,/close

!p.multi=0
!p.position=0

END
